@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.109 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: dun.c,v 1.117 2008/09/06 14:49:19 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -43,7 +43,7 @@
 /* ϩɽꥢμ */
 #define	AREA_PATH	-1
 
-/**** Ψ ****/
+/* Ψ */
 
 /* ꥢˤʤΨ */
 #define	RATE_ROOM	((rate_t)50)
@@ -83,9 +83,6 @@
 /* 1ֶᤤɥõƱΥˤȽǤΥ */
 #define	DOOR_NEAR_R	4
 
-/* ܥŪи볬ؿ */
-#define	DUN_LEV_BOSS	10
-
 /***************************************************************
 * ѿ
 ***************************************************************/
@@ -143,6 +140,14 @@ void	init_dun( void )
 	end_nest_flg( g_nest_flg_dun );
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_dun( void )
+{
+}
+
 /***************************************************************
 * 롦ѥκ֤
 * return : 롦ѥκ
@@ -357,11 +362,14 @@ void	up_dun( long d )
 	if( sgn_l( dun.lev ) >= +1 ){
 		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_FLOOR,
 				labs( dun.lev ) );
+		change_scene( SCENE_N_DUN );
 	} else if( sgn_l( dun.lev ) <= -1 ){
 		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_BASE,
 				labs( dun.lev ) );
+		change_scene( SCENE_N_DUN );
 	} else {
 		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_GROUND );
+		change_scene( SCENE_N_TOWN );
 	}
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
@@ -773,8 +781,8 @@ void	make_fence( void )
 * µܤ
 * room_ptn_t *ptn : Υѥ
 * area_t max_n : Υѥκ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 ***************************************************************/
 
 void	make_area( room_ptn_t *ptn, area_t max_n, long x, long y )
@@ -809,8 +817,8 @@ void	make_area( room_ptn_t *ptn, area_t max_n, long x, long y )
 * µܤܥ
 * room_ptn_t *ptn : Υѥ
 * area_t max_n : Υѥκ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 ***************************************************************/
 
 bool_t	make_area_boss( room_ptn_t *ptn, area_t max_n, long x, long y )
@@ -821,7 +829,7 @@ bool_t	make_area_boss( room_ptn_t *ptn, area_t max_n, long x, long y )
 		return FALSE;
 	if( dun.lev == 0 )
 		return FALSE;
-	if( (labs( dun.lev ) % DUN_LEV_BOSS) != 0 )
+	if( !chk_boss_dun_lev( dun.lev ) )
 		return FALSE;
 
 	n = labs( dun.lev ) / DUN_LEV_BOSS;
@@ -832,12 +840,23 @@ bool_t	make_area_boss( room_ptn_t *ptn, area_t max_n, long x, long y )
 	return TRUE;
 }
 
+/***************************************************************
+* µܤγؤܥФ뤫å
+* long dun_lev : µܤγ
+* return : ܥФ뤫?
+***************************************************************/
+
+bool_t	chk_boss_dun_lev( long dun_lev )
+{
+	return( (labs( dun_lev ) % DUN_LEV_BOSS) == 0 );
+}
+
 /***************************************************************
 * µܤ֤
 * room_ptn_t *room : Υѥ
 * area_t n : Υѥֹ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long flg_rev : 岼ȿžե饰
 ***************************************************************/
 
@@ -949,8 +968,8 @@ bool_t	chk_lighted_path( void )
 
 /***************************************************************
 * ϩ
-* long area_x : Xɸ
-* long area_y : Yɸ
+* long area_x : X ɸ
+* long area_y : Y ɸ
 ***************************************************************/
 
 void	make_path( long area_x, long area_y )
@@ -1024,10 +1043,10 @@ void	make_path( long area_x, long area_y )
 
 /***************************************************************
 * ٤ΥꥢϩӤƤ뤫Ĵ٤
-* long ax : ꥢXɸ
-* long ay : ꥢYɸ
+* long ax : ꥢ X ɸ
+* long ay : ꥢ Y ɸ
 * long d : (+)(-)λ
-* return : ٤ΥꥢϩYɸ
+* return : ٤ΥꥢϩY ɸ
 ***************************************************************/
 
 long	chk_extend_path_h( long ax, long ay, long d )
@@ -1058,10 +1077,10 @@ long	chk_extend_path_h( long ax, long ay, long d )
 
 /***************************************************************
 * ٤ΥꥢϩӤƤ뤫Ĵ٤̡
-* long ax : ꥢXɸ
-* long ay : ꥢYɸ
+* long ax : ꥢ X ɸ
+* long ay : ꥢ Y ɸ
 * long d : (+)(-)λ
-* return : ٤ΥꥢϩXɸ
+* return : ٤Υꥢϩ X ɸ
 ***************************************************************/
 
 long	chk_extend_path_v( long ax, long ay, long d )
@@ -1092,8 +1111,8 @@ long	chk_extend_path_v( long ax, long ay, long d )
 
 /***************************************************************
 * Υꥢɤå
-* long ax : ꥢXɸ
-* long ay : ꥢYɸ
+* long ax : ꥢ X ɸ
+* long ay : ꥢ Y ɸ
 * return : ?
 ***************************************************************/
 
@@ -1116,8 +1135,8 @@ bool_t	chk_room( long ax, long ay )
 
 /***************************************************************
 * ϩüޤǿФ
-* long mx : Xɸ
-* long my : Yɸ
+* long mx : X ɸ
+* long my : Y ɸ
 * long dx : ϩ򷡤(+)(-)
 * long dy : ϩ򷡤(+)(-)
 ***************************************************************/
@@ -1167,8 +1186,8 @@ void	finish_path( long mx, long my, long dx, long dy )
 
 /***************************************************************
 * ϩüޤǷ줿å
-* long mx : Xɸ
-* long my : Yɸ
+* long mx : X ɸ
+* long my : Y ɸ
 * long dx : ϩ򷡤(+)(-)
 * long dy : ϩ򷡤(+)(-)
 * return : ٽä?
@@ -1344,8 +1363,8 @@ bool_t	chk_finish_path( long mx, long my, long dx, long dy )
 
 /***************************************************************
 * ٤äɤĤʤ
-* long ax : ꥢXɸ
-* long ay : ꥢYɸ
+* long ax : ꥢ X ɸ
+* long ay : ꥢ Y ɸ
 * long dx : ϩ򷡤(+)(-)
 * long dy : ϩ򷡤(+)(-)
 ***************************************************************/
@@ -1395,8 +1414,8 @@ void	connect_room( long ax, long ay, long dx, long dy )
 
 /***************************************************************
 * ϩ˥ɥ
-* long mx : Xɸ
-* long my : Yɸ
+* long mx : X ɸ
+* long my : Y ɸ
 * long dx : (+)(-)
 * long dy : (+)(-)
 ***************************************************************/
@@ -1431,8 +1450,8 @@ void	make_door_path( long mx, long my, long dx, long dy )
 
 /***************************************************************
 * ޥåסơ֥ꤵ줿ɥ
-* long mx : Xɸ
-* long my : Yɸ
+* long mx : X ɸ
+* long my : Y ɸ
 ***************************************************************/
 
 void	make_door_room( long mx, long my )
@@ -1472,10 +1491,10 @@ void	make_door_room( long mx, long my )
 
 /***************************************************************
 * ɥ
-* long bx : Xɸ
-* long by : Yɸ
-* long ex : Xɸ
-* long ey : Yɸ
+* long bx :  X ɸ
+* long by :  Y ɸ
+* long ex :  X ɸ
+* long ey :  Y ɸ
 * char mnr : ޥʡδʸ
 * return : ɥ
 ***************************************************************/
@@ -1502,6 +1521,10 @@ door_t	*make_door( long bx, long by, long ex, long ey, char mnr )
 		flg &= ~(FLG_DOOR_CHKED);
 	} else if( mnr == FACE_MNR_GATE ){
 		flg |= FLG_DOOR_GATE;
+	} else if( mnr == FACE_MNR_WINDOW ){
+		mnr = FACE_MNR_WINDOW;
+	} else if( chk_face_window( bx, by, ex, ey ) ){
+		mnr = FACE_MNR_WINDOW;
 	} else {
 		flg |= FLG_DOOR_SHOP;
 	}
@@ -1509,12 +1532,55 @@ door_t	*make_door( long bx, long by, long ex, long ey, char mnr )
 	return make_door_flg( bx, by, ex, ey, mnr, flg );
 }
 
+/***************************************************************
+* ɥˤ뤫Ĵ٤
+* long bx :  X ɸ
+* long by :  Y ɸ
+* long ex :  X ɸ
+* long ey :  Y ɸ
+* return : ˤ뤫?
+***************************************************************/
+
+bool_t	chk_face_window( long bx, long by, long ex, long ey )
+{
+	long	x, y;
+
+	if( dun.lev != 0 )
+		return FALSE;
+
+	for( y = by; y <= ey; y++ ){
+		if( !clip_pos( bx - 1, y ) )
+			return FALSE;
+		if( dun.map.obj.mjr[y][bx - 1] != FACE_MJR_WALL )
+			return FALSE;
+
+		if( !clip_pos( ex + 1, y ) )
+			return FALSE;
+		if( dun.map.obj.mjr[y][ex + 1] != FACE_MJR_WALL )
+			return FALSE;
+	}
+
+	for( x = bx; x <= ex; x++ ){
+		if( !clip_pos( x, by - 1 ) )
+			return FALSE;
+		if( dun.map.obj.mjr[by - 1][x] != FACE_MJR_WALL )
+			return FALSE;
+
+		if( !clip_pos( x, ey + 1 ) )
+			return FALSE;
+		if( dun.map.obj.mjr[ey + 1][x] != FACE_MJR_WALL )
+			return FALSE;
+	}
+
+	return TRUE;
+}
+
 /***************************************************************
 * ե饰ꤷƥɥ
-* long bx : Xɸ
-* long by : Yɸ
-* long ex : Xɸ
-* long ey : Yɸ
+* long bx :  X ɸ
+* long by :  Y ɸ
+* long ex :  X ɸ
+* long ey :  Y ɸ
 * char mnr : ޥʡδʸ
 * flg_door_t flg : ɥΥե饰
 * return : ɥ
@@ -1610,9 +1676,12 @@ door_t	*make_door_flg(
 
 void	set_face_door( long dr_n )
 {
-	long	i, j;
+	door_t	*p;
 	char	mjr, mnr;
 	flg_map_t	flg;
+	long	i, j;
+
+	p = &(dun.door[dr_n]);
 
 	mjr = FACE_MJR_DOOR_CLOSE;
 	mnr = FACE_MNR_DOOR_NORM;
@@ -1620,38 +1689,43 @@ void	set_face_door( long dr_n )
 
 	/* if ʸν֤ */
 
-	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_OPEN ) ){
+	if( chk_flg( p->flg, FLG_DOOR_OPEN ) ){
 		mjr = FACE_MJR_DOOR_OPEN;
 		flg |= FLG_MAP_OBJ_PASS;
 	}
 
-	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_JAMMED ) )
+	if( chk_flg( p->flg, FLG_DOOR_JAMMED ) )
 		mnr = FACE_MNR_DOOR_JAMMED;
 
-	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_CHKED ) )
+	if( chk_flg( p->flg, FLG_DOOR_CHKED ) )
 		flg |= FLG_MAP_OBJ_FIND;
 	else
 		mnr = FACE_MNR_DOOR_NORM;
 
-	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_BROKEN ) ){
-		dun.door[dr_n].flg |= FLG_DOOR_OPEN;
+	if( chk_flg( p->flg, FLG_DOOR_BROKEN ) ){
+		p->flg |= FLG_DOOR_OPEN;
 		mjr = FACE_MJR_DOOR_OPEN;
 		mnr = FACE_MNR_DOOR_BROKEN;
 		flg |= FLG_MAP_OBJ_PASS;
 	}
 
-	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_SECRET ) ){
-		dun.door[dr_n].flg &= ~(FLG_DOOR_OPEN);
+	if( chk_face_window( p->x, p->y,
+			(p->x + p->dx - 1), (p->y + p->dy - 1) ) ){
+		mnr = FACE_MNR_WINDOW;
+	}
+
+	if( chk_flg( p->flg, FLG_DOOR_SECRET ) ){
+		p->flg &= ~(FLG_DOOR_OPEN);
 		mjr = FACE_MJR_DOOR_CLOSE;
 		mnr = FACE_MNR_DOOR_SECRET;
 		flg &= ~FLG_MAP_OBJ_PASS;
 		flg |= FLG_MAP_OBJ_LOOK_WALL;
 	}
 
-	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_SHOP ) ){
+	if( chk_flg( p->flg, FLG_DOOR_SHOP ) ){
 		mjr = FACE_MJR_DOOR_CLOSE;
 		/* mnr  make_door() Ѥ */
-		mnr = dun.door[dr_n].mnr;
+		mnr = p->mnr;
 		flg &= ~FLG_MAP_OBJ_PASS;
 		flg |= FLG_MAP_OBJ_FIND;
 	}
@@ -1661,7 +1735,7 @@ void	set_face_door( long dr_n )
 	if( dun.lev == 0 )
 		flg |= FLG_MAP_OBJ_FIND;
 
-	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_GATE ) ){
+	if( chk_flg( p->flg, FLG_DOOR_GATE ) ){
 		mjr = FACE_MJR_DOOR_CLOSE;
 		mnr = FACE_MNR_GATE;
 		flg &= ~FLG_MAP_OBJ_PASS;
@@ -1670,14 +1744,14 @@ void	set_face_door( long dr_n )
 
 	/**/
 
-	dun.door[dr_n].mjr = mjr;
-	dun.door[dr_n].mnr = mnr;
-	for( i = 0; i < dun.door[dr_n].dy; i++ ){
-		for( j = 0; j < dun.door[dr_n].dx; j++ ){
+	p->mjr = mjr;
+	p->mnr = mnr;
+	for( i = 0; i < p->dy; i++ ){
+		for( j = 0; j < p->dx; j++ ){
 			long	x, y;
 
-			x = dun.door[dr_n].x + j;
-			y = dun.door[dr_n].y + i;
+			x = p->x + j;
+			y = p->y + i;
 			dun.map.obj.mjr[y][x] = mjr;
 			dun.map.obj.mnr[y][x] = mnr;
 			dun.map.obj.flg[y][x] = flg;
@@ -1717,18 +1791,18 @@ bool_t	chk_find_door( long dr_n )
 * return : ɥ?
 ***************************************************************/
 
-bool_t	break_door( long dr_n )
+bool_t	break_door( chr_t *chr, long dr_n )
 {
 	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_SHOP ) ){
-		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_SHOP );
-		return FALSE;
-	}
-	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_BROKEN ) ){
-		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_BROKEN );
+		print_msg_mbr( chr, FLG_NULL, MSG_ERR_DOOR_BREAK_SHOP );
 		return FALSE;
 	}
 	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_GATE ) ){
-		print_msg( FLG_NULL, MSG_ERR_DOOR_BREAK_SHOP );
+		print_msg_mbr( chr, FLG_NULL, MSG_ERR_DOOR_BREAK_SHOP );
+		return FALSE;
+	}
+	if( chk_flg( dun.door[dr_n].flg, FLG_DOOR_BROKEN ) ){
+		print_msg_mbr( chr, FLG_NULL, MSG_ERR_DOOR_BREAK_BROKEN );
 		return FALSE;
 	}
 
@@ -1772,8 +1846,8 @@ void	get_near_pos_door( pos_t *pos, door_t *dr, chr_t *chr )
 
 /***************************************************************
 * ꥢνϩ˱ɥ
-* long ax : ꥢXɸ
-* long ay : ꥢYɸ
+* long ax : ꥢ X ɸ
+* long ay : ꥢ Y ɸ
 * return : ?
 ***************************************************************/
 
@@ -1808,8 +1882,8 @@ bool_t	make_hide_cross_path( long ax, long ay )
 
 /***************************************************************
 * ɥǤ뽽ϩĴ٤
-* long mx : Xɸ
-* long my : Yɸ
+* long mx : X ɸ
+* long my : Y ɸ
 * return : Ǥ뤫?
 ***************************************************************/
 
@@ -1880,8 +1954,8 @@ bool_t	chk_cross_path( long mx, long my )
 
 /***************************************************************
 * ϩ˱ɥ
-* long mx : Xɸ
-* long my : Yɸ
+* long mx : X ɸ
+* long my : Y ɸ
 ***************************************************************/
 
 void	hide_cross_path( long mx, long my )
@@ -1961,8 +2035,8 @@ void	make_stairs_randm( char face )
 
 /***************************************************************
 * ɸꤷơʤ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * char face : ʤμδʸ
 ***************************************************************/
 
@@ -1994,8 +2068,8 @@ void	make_stairs( long x, long y, char face )
 
 /***************************************************************
 * 
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dun_lev : µܤγ
 * bool_t flg_self : 饯Τ֤
 * return : Ǥ?
@@ -2023,8 +2097,8 @@ bool_t	set_statue( long x, long y, long dun_lev, bool_t flg_self )
 
 /***************************************************************
 * ޥåפγƥ쥤䡼쥤䡼򹹿
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dx : 
 * long dy : ⤵
 ***************************************************************/
@@ -2059,15 +2133,16 @@ void	set_map_total( long x, long y, long dx, long dy )
 
 /***************************************************************
 * طʥޥåפ쥤䡼򹹿
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dx : 
 * long dy : ⤵
 ***************************************************************/
 
 void	set_map_total_bg( long x, long y, long dx, long dy )
 {
-	long	i, j;
+	long	bx, by;
+	long	ex, ey;
 	long	xx, yy;
 	char	mjr, mnr;
 	curs_attr_n_t	attr_n;
@@ -2076,16 +2151,21 @@ void	set_map_total_bg( long x, long y, long dx, long dy )
 	attr_n = CURS_ATTR_N_MAP_NORMAL;
 	attr_dflt = get_curs_attr();
 
-	for( i = 0; i < dy; i++ ){
-		yy = y + i;
-		if( !clip_y( yy ) )
-			continue;
-
-		for( j = 0; j < dx; j++ ){
-			xx = x + j;
-			if( !clip_x( xx ) )
-				continue;
+	bx = x;
+	by = y;
+	ex = x + dx - 1;
+	ey = y + dy - 1;
+	if( bx < 0 )
+		bx = 0;
+	if( by < 0 )
+		by = 0;
+	if( ex > MAP_MAX_X - 1 )
+		ex = MAP_MAX_X - 1;
+	if( ey > MAP_MAX_Y - 1 )
+		ey = MAP_MAX_Y - 1;
 
+	for( yy = by; yy <= ey; yy++ ){
+		for( xx = bx; xx <= ex; xx++ ){
 			set_face_from_map_obj( TRUE, xx, yy, &mjr, &mnr );
 
 			dun.map.total.mjr[yy][xx] = mjr;
@@ -2098,8 +2178,9 @@ void	set_map_total_bg( long x, long y, long dx, long dy )
 
 /***************************************************************
 * طʥޥåפθδʸ֤
-* long x : Xɸ
-* long y : Yɸ
+* bool_t flg_chk_find : ĤäƤ뤫å뤫?
+* long x : X ɸ
+* long y : Y ɸ
 * char *mjr : ᥸㡼δʸ֤
 * char *mnr : ޥʡδʸ֤
 ***************************************************************/
@@ -2111,53 +2192,42 @@ void	set_face_from_map_obj(
 	flg_map_t	flg;
 	long	dep;
 
-	if( mjr != NULL )
-		*mjr = FACE_MJR_NULL;
-	if( mnr != NULL )
-		*mnr = FACE_MNR_NULL;
-
+	if( mjr == NULL )
+		return;
+	if( mnr == NULL )
+		return;
 	if( !clip_pos( x, y ) )
 		return;
 
-	if( mjr != NULL )
-		*mjr = dun.map.obj.mjr[y][x];
-	if( mnr != NULL )
-		*mnr = dun.map.obj.mnr[y][x];
+	*mjr = dun.map.obj.mjr[y][x];
+	*mnr = dun.map.obj.mnr[y][x];
 	flg = dun.map.obj.flg[y][x];
 	dep = calc_light_depth( x, y );
 
 	if( chk_flg( flg, FLG_MAP_OBJ_LOOK_WALL ) ){
-		if( mjr != NULL )
-			*mjr = FACE_MJR_WALL;
-		if( mnr != NULL )
-			*mnr = FACE_MNR_WALL;
+		*mjr = FACE_MJR_WALL;
+		*mnr = FACE_MNR_WALL;
 	}
 	if( chk_flg( flg, FLG_MAP_OBJ_LOOK_FLOOR ) ){
-		if( mjr != NULL )
-			*mjr = FACE_MJR_FLOOR;
-		if( mnr != NULL )
-			*mnr = FACE_MNR_FLOOR;
+		*mjr = FACE_MJR_FLOOR;
+		*mnr = FACE_MNR_FLOOR;
 	}
 	if( flg_chk_find ){
 		if( (*mjr == FACE_MJR_FLOOR) && (dep <= 0) ){
-			if( mjr != NULL )
-				*mjr = FACE_MJR_NULL;
-			if( mnr != NULL )
-				*mnr = FACE_MNR_NULL;
+			*mjr = FACE_MJR_NULL;
+			*mnr = FACE_MNR_NULL;
 		}
 		if( !chk_flg( flg, FLG_MAP_OBJ_FIND ) ){
-			if( mjr != NULL )
-				*mjr = FACE_MJR_NULL;
-			if( mnr != NULL )
-				*mnr = FACE_MNR_NULL;
+			*mjr = FACE_MJR_NULL;
+			*mnr = FACE_MNR_NULL;
 		}
 	}
 }
 
 /***************************************************************
 * °ޥåפ쥤䡼򹹿
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dx : 
 * long dy : ⤵
 ***************************************************************/
@@ -2178,17 +2248,26 @@ void	set_map_total_crsr_attr(
 	if( !clip_pos( crsr->x, crsr->y ) )
 		return;
 
+	if( (crsr->x + ptn->x + ptn->x_len - 1) < x )
+		return;
+	if( (crsr->y + ptn->y + ptn->y_len - 1) < y )
+		return;
+	if( (crsr->x + ptn->x) > (x + dx - 1) )
+		return;
+	if( (crsr->y + ptn->y) > (y + dy - 1) )
+		return;
+
 	attr_dflt = get_curs_attr();
 	attr_n = CURS_ATTR_N_MAP_CRSR;
 	for( i = 0; i < ptn->y_len; i++ ){
-		yy = crsr->y + i + ptn->y;
+		yy = crsr->y + ptn->y + i;
 		if( !clip_y( yy ) )
 			continue;
 
 		for( j = 0; j < ptn->x_len; j++ ){
 			long	c;
 
-			xx = crsr->x + j + ptn->x;
+			xx = crsr->x + ptn->x + j;
 			if( !clip_x( xx ) )
 				continue;
 
@@ -2205,8 +2284,8 @@ void	set_map_total_crsr_attr(
 
 /***************************************************************
 * ֥ȤΥޥåפ쥤䡼򹹿
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dx : 
 * long dy : ⤵
 ***************************************************************/
@@ -2275,8 +2354,8 @@ void	set_map_total_obj( long x, long y, long dx, long dy )
 
 /***************************************************************
 * 󥫡Υޥåפ쥤䡼򹹿
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dx : 
 * long dy : ⤵
 ***************************************************************/
@@ -2288,11 +2367,20 @@ void	set_map_total_square( long x, long y, long dx, long dy )
 	curs_attr_t	*attr_dflt;
 	party_t	*pty;
 
-	attr_dflt = get_curs_attr();
 	pty = get_party();
 
 	if( !clip_pos( pty->square.x, pty->square.y ) )
 		return;
+	if( (pty->square.x + 1) < x )
+		return;
+	if( (pty->square.y + 1) < y )
+		return;
+	if( (pty->square.x - 1) > (x + dx - 1) )
+		return;
+	if( (pty->square.y - 1) > (y + dy - 1) )
+		return;
+
+	attr_dflt = get_curs_attr();
 
 	for( i = -1; i <= +1; i++ ){
 		yy = pty->square.y + i;
@@ -2325,15 +2413,16 @@ void	set_map_total_square( long x, long y, long dx, long dy )
 
 /***************************************************************
 * 󥹥ȥСΥޥåפ쥤䡼򹹿
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dx : 
 * long dy : ⤵
 ***************************************************************/
 
 void	set_map_total_chr( long x, long y, long dx, long dy )
 {
-	long	i, j;
+	long	bx, by;
+	long	ex, ey;
 	long	xx, yy;
 	char	mjr, mnr;
 	flg_map_t	flg, flg_total;
@@ -2343,16 +2432,22 @@ void	set_map_total_chr( long x, long y, long dx, long dy )
 
 	attr_dflt = get_curs_attr();
 
-	for( i = 0; i < dy; i++ ){
-		yy = y + i;
-		if( !clip_y( yy ) )
-			continue;
-		for( j = 0; j < dx; j++ ){
-			bool_t	flg_rev_rev;
+	bx = x;
+	by = y;
+	ex = x + dx - 1;
+	ey = y + dy - 1;
+	if( bx < 0 )
+		bx = 0;
+	if( by < 0 )
+		by = 0;
+	if( ex > MAP_MAX_X - 1 )
+		ex = MAP_MAX_X - 1;
+	if( ey > MAP_MAX_Y - 1 )
+		ey = MAP_MAX_Y - 1;
 
-			xx = x + j;
-			if( !clip_x( xx ) )
-				continue;
+	for( yy = by; yy <= ey; yy++ ){
+		for( xx = bx; xx <= ex; xx++ ){
+			bool_t	flg_rev_rev;
 
 			flg_total = dun.map.total.flg[yy][xx];
 
@@ -2408,8 +2503,8 @@ void	set_map_total_chr( long x, long y, long dx, long dy )
 
 /***************************************************************
 * ΥѥΥޥåפ쥤䡼򹹿
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dx : 
 * long dy : ⤵
 ***************************************************************/
@@ -2429,15 +2524,24 @@ void	set_map_total_crsr_ptn(
 	if( !clip_pos( crsr->x, crsr->y ) )
 		return;
 
+	if( (crsr->x + ptn->x + ptn->x_len - 1) < x )
+		return;
+	if( (crsr->y + ptn->y + ptn->y_len - 1) < y )
+		return;
+	if( (crsr->x + ptn->x) > (x + dx - 1) )
+		return;
+	if( (crsr->y + ptn->y) > (y + dy - 1) )
+		return;
+
 	for( i = 0; i < ptn->y_len; i++ ){
-		yy = crsr->y + i + ptn->y;
+		yy = crsr->y + ptn->y + i;
 		if( !clip_y( yy ) )
 			continue;
 
 		for( j = 0; j < ptn->x_len; j++ ){
 			long	c;
 
-			xx = crsr->x + j + ptn->x;
+			xx = crsr->x + ptn->x + j;
 			if( !clip_x( xx ) )
 				continue;
 
@@ -2460,10 +2564,10 @@ void	set_map_total_crsr_ptn(
 
 /***************************************************************
 * ϩ
-* long x1 : Xɸ
-* long y1 : Yɸ
-* long x2 : Xɸ
-* long y2 : Yɸ
+* long x1 :  X ɸ
+* long y1 :  Y ɸ
+* long x2 :  X ɸ
+* long y2 :  Y ɸ
 * sect_t sect : ʸ
 ***************************************************************/
 
@@ -2498,8 +2602,8 @@ void	line_path( long x1, long y1, long x2, long y2, sect_t sect )
 
 /***************************************************************
 * ɸϩ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long dx : 
 * long dy : ⤵
 * sect_t sect : ʸ
@@ -2713,8 +2817,8 @@ bool_t	srch_door( long n )
 
 /***************************************************************
 * ϰϤΥɥĴ٤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long r : Ⱦ
 ***************************************************************/
 
@@ -2738,8 +2842,8 @@ void	detect_door( long x, long y, long r )
 
 /***************************************************************
 * ɸΥޥåפȯ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 ***************************************************************/
 
 void	find_obj( long x, long y )
@@ -2777,8 +2881,8 @@ void	find_obj( long x, long y )
 /***************************************************************
 * ΤĤƤ륻äˡ
 * Υȯ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 ***************************************************************/
 
 void	find_obj_fill( long x, long y )
@@ -2810,8 +2914,8 @@ void	find_obj_fill( long x, long y )
 
 /***************************************************************
 * ꥻȯ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 ***************************************************************/
 
 void	find_obj_fill_field( long x, long y )
@@ -2835,8 +2939,8 @@ void	find_obj_fill_field( long x, long y )
 
 /***************************************************************
 * ꥢĤ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * bool_t flg_find : ȯ뤫?
 ***************************************************************/
 
@@ -2847,8 +2951,8 @@ void	on_light_area( long x, long y, bool_t flg_find )
 
 /***************************************************************
 * ꥢä
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * bool_t flg_find : ȯ뤫?
 ***************************************************************/
 
@@ -2859,8 +2963,8 @@ void	off_light_area( long x, long y, bool_t flg_find )
 
 /***************************************************************
 * ꥢĤäꤹ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * bool_t flg_on : Ĥ뤫ä?
 * bool_t flg_find : ȯ뤫?
 ***************************************************************/
@@ -2887,8 +2991,8 @@ void	turn_light_area( long x, long y, bool_t flg_on, bool_t flg_find )
 
 /***************************************************************
 * ɸĤäꤹ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * sect_t sect : ʸ
 * bool_t flg_on : Ĥ뤫ä?
 * bool_t flg_find : ȯ뤫?
@@ -2965,8 +3069,8 @@ void	turn_light_door( door_t *dr, bool_t flg_on, bool_t flg_find )
 
 /***************************************************************
 * ꥪ֥ȤˤĤäꤹ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * bool_t flg_on : Ĥ뤫ä?
 * return : 뤯ʤä?
 ***************************************************************/
@@ -2983,8 +3087,8 @@ bool_t	turn_light_obj( long x, long y, bool_t flg_on )
 
 /***************************************************************
 * 饯ˤĤäꤹ
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * bool_t flg_on : Ĥ뤫ä?
 * return : 뤯ʤä?
 ***************************************************************/
@@ -3001,8 +3105,8 @@ bool_t	turn_light_chr( long x, long y, bool_t flg_on )
 
 /***************************************************************
 * ɸ뤵οĴ٤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * return : 뤵ο
 ***************************************************************/
 
@@ -3103,8 +3207,8 @@ long	get_dun_lev( void )
 
 /***************************************************************
 * ɸˤɥΥǡ֤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * return : ɥΥǡ
 ***************************************************************/
 
@@ -3125,8 +3229,8 @@ door_t	*get_door( long x, long y )
 
 /***************************************************************
 * ɸ1ֶᤤɥΥǡ֤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * act_kind_t act_kind : ɥФ륢
 * return : ɥΥǡ
 ***************************************************************/
@@ -3179,8 +3283,8 @@ door_t	*get_door_nearest( long x, long y, act_kind_t act_kind )
 
 /***************************************************************
 * ɸˤʤ٤ᤤɥΥǡ֤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * act_kind_t act_kind : ɥФ륢
 * return : ɥΥǡ
 ***************************************************************/
@@ -3290,8 +3394,8 @@ door_t	*get_door_disperse( mbr_t *mbr, act_kind_t act_kind )
 
 /***************************************************************
 * Ƥϰǡ˥ɥΥǡ֤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * act_kind_t act_kind : ɥФ륢
 * return : ɥΥǡ
 ***************************************************************/
@@ -3332,8 +3436,8 @@ door_t	*get_door_randm( long x, long y, act_kind_t act_kind )
 
 /***************************************************************
 * ν̱˶ᤤʥɥΥǡ֤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * long r : Ⱦ
 * return : ɥΥǡ
 ***************************************************************/
@@ -3558,10 +3662,50 @@ bool_t	chk_stairs( long face )
 	return TRUE;
 }
 
+/***************************************************************
+* ʸꤷƥޥåפ򸡺
+* char face_mjr : ᥸㡼δʸ
+* char face_mnr : ޥʡδʸ
+* long *x :  X ɸ - 1 ꤹ롣X ɸ֤
+* long *y :  Y ɸꤹ롣Y ɸ֤
+* return : Ĥä?
+***************************************************************/
+
+bool_t	srch_map_obj( char face_mjr, char face_mnr, long *x, long *y )
+{
+	long	xx, yy;
+
+	if( (*x == MAP_DEL_X) || (*y == MAP_DEL_Y) ){
+		xx = 0;
+		yy = 0;
+	} else {
+		xx = *x + 1;
+		yy = *y;
+	}
+
+	for( ; yy < MAP_MAX_Y; yy++, xx = 0 ){
+		for( ; xx < MAP_MAX_X; xx++ ){
+			if( face_mjr != '\0' )
+				if( dun.map.obj.mjr[yy][xx] != face_mjr )
+					continue;
+			if( face_mnr != '\0' )
+				if( dun.map.obj.mnr[yy][xx] != face_mnr )
+					continue;
+
+			*x = xx;
+			*y = yy;
+
+			return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
 /***************************************************************
 * ɸɤĴ٤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * return : ɤ?
 ***************************************************************/
 
@@ -3581,8 +3725,8 @@ bool_t	is_map_wall( long x, long y )
 
 /***************************************************************
 * ɸޥåפͭϰ⤫Ĵ٤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * return : ޥåפͭϰ⤫?
 ***************************************************************/
 
@@ -3597,8 +3741,8 @@ bool_t	clip_pos( long x, long y )
 }
 
 /***************************************************************
-* Xɸޥåפͭϰ⤫Ĵ٤
-* long n : Xɸ
+*  X ɸޥåפͭϰ⤫Ĵ٤
+* long n : X ɸ
 * return : ޥåפͭϰ⤫?
 ***************************************************************/
 
@@ -3615,8 +3759,8 @@ bool_t	clip_x( long n )
 }
 
 /***************************************************************
-* Yɸޥåפͭϰ⤫Ĵ٤
-* long n : Yɸ
+*  Y ɸޥåפͭϰ⤫Ĵ٤
+* long n : Y ɸ
 * return : ޥåפͭϰ⤫?
 ***************************************************************/
 
@@ -3634,8 +3778,8 @@ bool_t	clip_y( long n )
 
 /***************************************************************
 * ɸޥåפɽϰ⤫Ĵ٤
-* long x : Xɸ
-* long y : Yɸ
+* long x : X ɸ
+* long y : Y ɸ
 * return : ޥåפɽϰ⤫?
 ***************************************************************/
 
@@ -3650,8 +3794,8 @@ bool_t	clip_draw_pos( long x, long y )
 }
 
 /***************************************************************
-* Xɸޥåפɽϰ⤫Ĵ٤
-* long n : Xɸ
+*  X ɸޥåפɽϰ⤫Ĵ٤
+* long n : X ɸ
 * return : ޥåפɽϰ⤫?
 ***************************************************************/
 
@@ -3678,8 +3822,8 @@ bool_t	clip_draw_x( long n )
 }
 
 /***************************************************************
-* Yɸޥåפɽϰ⤫Ĵ٤
-* long n : Yɸ
+*  Y ɸޥåפɽϰ⤫Ĵ٤
+* long n : Y ɸ
 * return : ޥåפɽϰ⤫?
 ***************************************************************/
 
@@ -3799,15 +3943,21 @@ char	get_chr_mnr_crsr( void )
 
 char	get_chr_crsr( bool_t flg_mjr )
 {
+	char	face;
 	pos_t	*crsr = get_crsr();
 
+	if( flg_mjr )
+		face = FACE_MJR_NULL;
+	else
+		face = FACE_MNR_NULL;
+
 	if( crsr == NULL )
-		return FACE_MJR_NULL;
+		return face;
 
 	if( !clip_x( crsr->x ) )
-		return FACE_MJR_NULL;
+		return face;
 	if( !clip_y( crsr->y ) )
-		return FACE_MJR_NULL;
+		return face;
 
 	if( flg_mjr )
 		return( dun.map.chr.mjr[crsr->y][crsr->x] );
