@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.21 2008/04/12 12:21:28 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.23 2008/05/18 19:49:18 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -992,6 +992,26 @@ light_kind_t	g_light_trans_tab[] = {
 	LIGHT_KIND_LAMP,
 };
 
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ˾ߤɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ˾ߤ WISH_LEVEL_NULL ǡ롣
+***************************************************************/
+
+wish_level_t	g_wish_level_trans_tab[] = {
+	WISH_LEVEL_NULL,
+	WISH_LEVEL_ARMAGEDDON,
+	WISH_LEVEL_DAEMON,
+	WISH_LEVEL_DJINNI,
+	WISH_LEVEL_GOD,
+};
+
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
