@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.192 2008/05/10 09:43:36 bowkenken Exp $
+* $Id: gfile.c,v 1.200 2008/09/07 11:31:27 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -102,7 +102,7 @@ void	init_game_file( void )
 			FILE_NAME_MAX_LEN );
 
 	if( !chk_exist_file( path_name_game_conf ) )
-		about_game();
+		about_game( TRUE );
 }
 
 /***************************************************************
@@ -133,7 +133,7 @@ char	*init_dir_game( char *home, char *dir, bool_t flg_GPL )
 
 	/* ̵ GPL ɽ */
 	if( flg_GPL )
-		about_game();
+		about_game( TRUE );
 
 	/* ̵к */
 	if( make_dir( name ) )
@@ -173,7 +173,8 @@ void	get_path_game_data_txt( char *path, long n )
 		return;
 	}
 
-	sprintf( path, "%s/%s%02ld%s",
+	sn_printf( path, FILE_NAME_MAX_LEN,
+			"%s/%s%02ld%s",
 			dir_name_game_data_txt,
 			STR_FILE_NAME_GAME_DATA_TXT,
 			n,
@@ -193,7 +194,8 @@ void	get_path_game_data_bin( char *path, long n )
 		return;
 	}
 
-	sprintf( path, "%s/%s%02ld%s",
+	sn_printf( path, FILE_NAME_MAX_LEN,
+			"%s/%s%02ld%s",
 			dir_name_game_data_bin,
 			STR_FILE_NAME_GAME_DATA_BIN,
 			n,
@@ -213,7 +215,8 @@ void	get_path_game_data_cnf( char *path, long n )
 		return;
 	}
 
-	sprintf( path, "%s/%s%02ld%s",
+	sn_printf( path, FILE_NAME_MAX_LEN,
+			"%s/%s%02ld%s",
 			dir_name_game_data_cnf,
 			STR_FILE_NAME_GAME_DATA_CNF,
 			n,
@@ -233,7 +236,8 @@ void	get_path_game_data_rep( char *path, long n )
 		return;
 	}
 
-	sprintf( path, "%s/%s%02ld%s",
+	sn_printf( path, FILE_NAME_MAX_LEN,
+			"%s/%s%02ld%s",
 			dir_name_game_data_rep,
 			STR_FILE_NAME_GAME_DATA_REP,
 			n,
@@ -247,7 +251,8 @@ void	get_path_game_data_rep( char *path, long n )
 
 void	get_path_bug_repo_txt( char *path )
 {
-	sprintf( path, "%s/%s%s",
+	sn_printf( path, FILE_NAME_MAX_LEN,
+			"%s/%s%s",
 			dir_name_bug_repo,
 			STR_FILE_NAME_BUG_REPO_TXT,
 			STR_EXT_NAME_BUG_REPO_TXT );
@@ -260,7 +265,8 @@ void	get_path_bug_repo_txt( char *path )
 
 void	get_path_bug_repo_bin( char *path )
 {
-	sprintf( path, "%s/%s%s",
+	sn_printf( path, FILE_NAME_MAX_LEN,
+			"%s/%s%s",
 			dir_name_bug_repo,
 			STR_FILE_NAME_BUG_REPO_BIN,
 			STR_EXT_NAME_BUG_REPO_BIN );
@@ -273,7 +279,8 @@ void	get_path_bug_repo_bin( char *path )
 
 void	get_path_bug_repo_cnf( char *path )
 {
-	sprintf( path, "%s/%s%s",
+	sn_printf( path, FILE_NAME_MAX_LEN,
+			"%s/%s%s",
 			dir_name_bug_repo,
 			STR_FILE_NAME_BUG_REPO_CNF,
 			STR_EXT_NAME_BUG_REPO_CNF );
@@ -286,7 +293,8 @@ void	get_path_bug_repo_cnf( char *path )
 
 void	get_path_bug_repo_rep( char *path )
 {
-	sprintf( path, "%s/%s%s",
+	sn_printf( path, FILE_NAME_MAX_LEN,
+			"%s/%s%s",
 			dir_name_bug_repo,
 			STR_FILE_NAME_BUG_REPO_REP,
 			STR_EXT_NAME_BUG_REPO_REP );
@@ -616,9 +624,8 @@ rc_token_t	rc_lex( FILE *fp, rc_union_t *u, bool_t flg_err_exit )
 
 			c = rc_lex_getc( fp, TRUE, flg_err_exit );
 			if( c != '\'' ){
-				print_lex_err( MSG_S, MSG_ERR_RC_LEX_CHAR );
-				if( flg_err_exit )
-					exit_game( EXIT_FAILURE );
+				rc_lex_ungetc( fp, c );
+				print_lex_wrn( MSG_S, MSG_ERR_RC_LEX_CHAR );
 			}
 			return RC_TOKEN_CHAR;
 		case '\"':
@@ -772,6 +779,10 @@ rc_token_t	rc_lex_char( FILE *fp, rc_union_t *u, bool_t flg_err_exit )
 			return RC_TOKEN_EOF;
 
 		cc = toupper( c ) - '@';
+	} else if( c == '\'' ){
+		/* ʸλ */
+		rc_lex_ungetc( fp, c );
+		cc = ' ';
 	} else {
 		cc = c;
 	}
@@ -991,7 +1002,7 @@ bool_t	rename_back_up_file( char *fname )
 		path_len = FILE_NAME_MAX_LEN;
 
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
-		sprintf( str_n, STR_EXT_NAME_BAK_1, i );
+		sn_printf( str_n, 15, STR_EXT_NAME_BAK_1, i );
 
 		str_nz_cpy( bak_fname, fname, FILE_NAME_MAX_LEN );
 		bak_fname[FILE_NAME_MAX_LEN] = '\0';
@@ -2232,6 +2243,48 @@ long	trans_light_kind_to_idx( light_kind_t k )
 	return 0;
 }
 
+/***************************************************************
+* ǥå˾ߤμѴ
+* long idx : ǥå
+* return : ˾ߤμ
+***************************************************************/
+
+wish_level_t	trans_idx_to_wish_level( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_wish_level_trans_tab )
+			/ sizeof( g_wish_level_trans_tab[0] );
+
+	if( idx < 0 )
+		return WISH_LEVEL_NULL;
+	if( idx >= max_idx )
+		return WISH_LEVEL_NULL;
+
+	return( g_wish_level_trans_tab[idx] );
+}
+
+/***************************************************************
+* ˾ߤμफ饤ǥåѴ
+* wish_level_t k : ˾ߤμ
+* return : ǥå
+***************************************************************/
+
+long	trans_wish_level_to_idx( wish_level_t k )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_wish_level_trans_tab )
+			/ sizeof( g_wish_level_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_wish_level_trans_tab[i] == k )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ǥå鿩μѴ
 * long idx : ǥå
@@ -2849,22 +2902,22 @@ bool_t	make_dir_node( char *path )
 {
 	if( path == NULL )
 		return FALSE;
-#ifdef	D_DOS
+#if	defined( D_DOS )
 	if( _mkdir( path ) )
 		return TRUE;
 	else
 		return FALSE;
-#elif	HAVE_MKDIR
+#elif	defined( HAVE_MKDIR )
 	if( mkdir( path, S_IFDIR | 0755 ) == 0 )
 		return TRUE;
 	else
 		return FALSE;
-#else	/* HAVE_MKDIR */
+#else
 	if( mknod( path, S_IFDIR | 0755, 0 ) == 0 )
 		return TRUE;
 	else
 		return FALSE;
-#endif	/* HAVE_MKDIR */
+#endif
 	return FALSE;
 }
 
@@ -3146,7 +3199,7 @@ long	save_crypt_tab( FILE *fp, const char *s, ... )
 	long	i;
 
 	va_start( argptr, s );
-	vsprintf( buf, s, argptr );
+	vsn_printf( buf, 1024, s, argptr );
 	va_end( argptr );
 
 	for( i = 0; i < g_tab_lev; i++ )
@@ -3171,7 +3224,7 @@ long	save_crypt_str( FILE *fp, const char *s, ... )
 	va_list	argptr;
 
 	va_start( argptr, s );
-	vsprintf( buf, s, argptr );
+	vsn_printf( buf, 1024, s, argptr );
 	va_end( argptr );
 
 	if( g_flg_crypt_txt ){
@@ -3277,7 +3330,7 @@ long	load_crypt_c( FILE *fp )
 				return '\n';
 			} else {
 				print_err( MSG_S, MSG_ERR_LOAD_BIN );
-//@@@				exit_game( EXIT_FAILURE );
+				exit_game( EXIT_FAILURE );
 			}
 		}
 	}
