@@ -5,11 +5,13 @@ extern "C" {
 #endif
 
 void	init_var_misc_menu( void );
+void	reset_static_misc_menu( void );
 void	init_misc_menu( void );
 char	*cb_menu_misc( menu_t **pp, menu_t **dflt );
 char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt );
-bool_t	chk_continue_exec_mode( void );
-bool_t	set_continue_exec_mode( void );
+bool_t	chk_continue_exec_mode( long *c, bool_t *p_flg_clr_key_buf );
+bool_t	get_continue_exec_mode( void );
+bool_t	toggle_continue_exec_mode( void );
 bool_t	clr_continue_exec_mode( void );
 char	*cb_menu_stairs( menu_t **pp, menu_t **dflt );
 char	*cb_menu_stairs_up( menu_t **pp, menu_t **dflt );
@@ -25,16 +27,29 @@ char	*cb_menu_show_map_hint( menu_t **pp, menu_t **dflt );
 void	show_map_hint( long x, long y );
 void	show_map_hint_chr( long x, long y );
 void	show_map_hint_obj( long x, long y );
+const char	*get_str_map_hint_chr( long x, long y );
+const char	*get_str_map_hint_obj( long x, long y );
 char	*cb_menu_chr_data( menu_t **pp, menu_t **dflt );
 char	*menu_sel_mbr_data( void );
-long	menu_show_mbr_data( mbr_t *mbr, long *page_n );
-long	menu_edit_mbr_data( mbr_t *mbr, long *page_n );
+long	menu_show_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n );
+long	menu_edit_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n );
 long	menu_mbr_data(
-	mbr_t *org_p, long *page_n,
+	mbr_t *org_p, long *page_n, data_n_t *data_n,
 	mbr_data_edit_kind_t edit_kind
 );
-long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n );
+long	menu_mbr_data_sub(
+	mbr_t *org_p, long *page_n, data_n_t *data_n,
+	mbr_data_edit_kind_t edit_kind
+);
+void	set_data_n( data_n_t data_n );
+long	get_mbr_data_page_n( void );
+void	set_mbr_data_page_n( long n );
+mbr_data_edit_kind_t	get_mbr_data_edit_kind( void );
+void	exec_menu_edit_mbr_data(
+	mbr_t *mbr, data_n_t n, long *mbr_dn, long *page_dn
+);
 bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p );
+void	sel_mbr_graph_file( mbr_t *mbr );
 char	*menu_sel_mnstr_data( void );
 char	*cb_menu_gold( menu_t **pp, menu_t **dflt );
 char	*cb_menu_collect_gold( menu_t **pp, menu_t **dflt );
@@ -52,6 +67,8 @@ void	move_crsr_abs( long x, long y );
 void	move_crsr_rel( long dx, long dy );
 char	*cb_menu_crsr_quick_move( menu_t **pp, menu_t **dflt );
 void	jump_crsr( long dx, long dy );
+char	*cb_menu_crsr_scroll( menu_t **pp, menu_t **dflt );
+void	crsr_scroll( long dx, long dy );
 char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt );
 char	*menu_crsr_move_mbr_n( long mbr_n );
 char	*menu_crsr_move_mbr( mbr_t *mbr );
@@ -108,6 +125,9 @@ void	set_scroll_smooth( void );
 void	set_scroll_center( void );
 char	*cb_menu_redraw_every_turn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
+char	*cb_menu_screen_size_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_screen_size_auto( menu_t **pp, menu_t **dflt );
+char	*cb_menu_screen_size_lines( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx_mbr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx_mnstr( menu_t **pp, menu_t **dflt );
@@ -150,25 +170,35 @@ char	*cb_menu_user_new_reg_macro( menu_t **pp, menu_t **dflt );
 char	*menu_user_new_sub(
 	menu_t **pp, menu_t **dflt, bool_t flg_reg_macro
 );
+char	*cb_menu_user_arrange_up( menu_t **pp, menu_t **dflt );
+char	*cb_menu_user_arrange_down( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_arrange_top( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_arrange_bottom( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove( menu_t **pp, menu_t **dflt );
 void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl );
+char	*cb_menu_user_arrange_up_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_user_arrange_down_sel( menu_t **pp, menu_t **dflt );
+char	*arrange_menu_user_1( long n, long d );
 char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_system( menu_t **pp, menu_t **dflt );
+char	*cb_menu_command( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_load( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_save( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_debug( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_bug_repo( menu_t **pp, menu_t **dflt );
 long	menu_replay_sel_load( void );
 char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt );
-char	*cb_menu_system( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt );
-char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt );
-char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_add_turn_hour( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_add_turn_minute( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_add_turn_turn( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_up_exp( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_up_lev( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard_scene( menu_t **pp, menu_t **dflt );
 char	*cb_menu_out_map_file( menu_t **pp, menu_t **dflt );
 char	*cb_menu_shell( menu_t **pp, menu_t **dflt );
 char	*cb_menu_about_game( menu_t **pp, menu_t **dflt );
