@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.41 2008/04/06 08:00:04 bowkenken Exp $
+* $Id: imenu.c,v 1.59 2008/09/20 23:54:14 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -33,6 +33,8 @@
 
 /**/
 
+#define	FLAG_CONTINUE_EXEC_KEY_IDLE	0
+
 #define	MENU_LANG_LS_N_PER_PAGE	10
 
 #define	SCROLL_WIDTH	(WIN_MAP_WIDTH / 2)
@@ -57,17 +59,59 @@ static char	g_user_menu_cmd[USER_MENU_MAX_N][MACRO_MAX_LEN + 1];
 static long	g_replay_sel_load_n;
 static menu_t	ls_menu_replay_sel_load[MENU_SAVE_LOAD_MAX_N * 2];
 
+static long	*g_page_n;
+static data_n_t	*g_data_n;
+static mbr_data_edit_kind_t	g_mbr_data_edit_kind;
+
 /**/
 
 #include	"imenu-tab.h"
 
 /**/
 
+static long	static_cb_menu_wizard_add_turn__hour;
+static long	static_cb_menu_wizard_add_turn__minute;
+static long	static_cb_menu_wizard_add_turn__turn;
+static long	static_cb_menu_wizard_up_exp__exp;
+
+/**/
+
 void	init_var_misc_menu( void )
 {
 	clr_user_menu();
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_misc_menu( void )
+{
+	pos_t	*crsr = get_crsr();
+	party_t *pty = get_party();
+	long	i;
+
+	g_menu_dflt_misc = NULL;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ )
+		g_ls_flg_srch[i] = TRUE;
+
+	g_next_pos.kind = NEXT_POS_KIND_SQUARE;
+	g_next_pos.p = &(pty->square);
+	g_next_pos.n = 0;
+	g_next_pos.x = 0;
+	g_next_pos.y = 0;
+	crsr->x = 0;
+	crsr->y = 0;
+
+	/**/
+
+	static_cb_menu_wizard_add_turn__hour = 0;
+	static_cb_menu_wizard_add_turn__minute = 0;
+	static_cb_menu_wizard_add_turn__turn = 0;
+	static_cb_menu_wizard_up_exp__exp = +(100 * 100 * 100);
+}
+
 /**/
 
 void	init_misc_menu( void )
@@ -80,6 +124,9 @@ void	init_misc_menu( void )
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ )
 		g_ls_flg_srch[i] = TRUE;
+
+	g_data_n = NULL;
+	g_mbr_data_edit_kind = MBR_DATA_EDIT_KIND_SHOW;
 }
 
 /**/
@@ -96,29 +143,43 @@ char	*cb_menu_misc( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt )
 {
-	set_continue_exec_mode();
+	toggle_continue_exec_mode();
 
 	return NULL;
 }
 
 /**/
 
-bool_t	chk_continue_exec_mode( long *c )
+bool_t	chk_continue_exec_mode( long *c, bool_t *p_flg_clr_key_buf )
 {
+#if	FLAG_CONTINUE_EXEC_KEY_IDLE
 	static bool_t	flg_pre_null = TRUE;
 
 	if( !get_continue_exec_mode() )
 		return FALSE;
 
-	if( flg_pre_null ){
+	if( flg_pre_null )
 		*c = '.';
-		flg_pre_null = FALSE;
-	} else {
-		*c = '|';
-		flg_pre_null = TRUE;
-	}
+	else
+		*c = CMD_KEY_IDLE;
+	flg_pre_null = !flg_pre_null;
+
+	*p_flg_clr_key_buf = TRUE;
+
+	call_sleep( 1000 * 3 / 60 / 2 );
 
 	return TRUE;
+#else
+	if( !get_continue_exec_mode() )
+		return FALSE;
+
+	*c = '.';
+	*p_flg_clr_key_buf = TRUE;
+
+	call_sleep( 1000 * 3 / 60 / 1 );
+
+	return TRUE;
+#endif
 }
 
 /**/
@@ -130,9 +191,9 @@ bool_t	get_continue_exec_mode( void )
 
 /**/
 
-bool_t	set_continue_exec_mode( void )
+bool_t	toggle_continue_exec_mode( void )
 {
-	g_flg_continue_exec_mode = TRUE;
+	g_flg_continue_exec_mode = !g_flg_continue_exec_mode;
 
 	call_gui_map_cont_exec_set(
 			g_flg_continue_exec_mode );
@@ -270,7 +331,8 @@ char	*cb_menu_srch( menu_t **pp, menu_t **dflt )
 	k++;
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
-		sprintf( ls[k].path, "/search/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/search/%ld", i );
 		str_nz_cpy( ls[k].kind, "<CheckItem>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
@@ -310,7 +372,8 @@ char	*cb_menu_srch_init( menu_t **pp, menu_t **dflt )
 	long	i;
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
-		sprintf( sub_path, "%ld", i );
+		sn_printf( sub_path, MENU_PATH_MAX_LEN,
+				"%ld", i );
 
 		if( chk_flg( pty->mbr[i]->stat, FLG_STAT_NOT_EXIST ) ){
 			set_flg_menu( *pp, sub_path, FLG_MENU_HIDDEN );
@@ -437,7 +500,30 @@ void	show_map_hint( long x, long y )
 
 void	show_map_hint_chr( long x, long y )
 {
-	dun_t	*dun = get_dun();
+	const char	*s;
+
+	s = get_str_map_hint_chr( x, y );
+	if( (s != NULL) && (s[0] != '\0') )
+		print_msg( FLG_NULL, s );
+}
+
+/**/
+
+void	show_map_hint_obj( long x, long y )
+{
+	const char	*s;
+
+	s = get_str_map_hint_obj( x, y );
+	if( (s != NULL) && (s[0] != '\0') )
+		print_msg( FLG_NULL, s );
+}
+
+/**/
+
+const char	*get_str_map_hint_chr( long x, long y )
+{
+	static char	buf[SCREEN_WIDTH * 2 + 1];
+	dun_t	*dun;
 	char	mjr, mnr;
 	flg_map_t	flg;
 	char	*msg1, *msg2;
@@ -445,16 +531,17 @@ void	show_map_hint_chr( long x, long y )
 	mnstr_t	*mnstr;
 
 	if( !clip_pos( x, y ) )
-		return;
+		return "";
 
+	dun = get_dun();
 	mjr = dun->map.chr.mjr[y][x];
 	mnr = dun->map.chr.mnr[y][x];
 	flg = dun->map.chr.flg[y][x];
 
 	if( !chk_flg( flg, FLG_MAP_CHR_FIND ) )
-		return;
+		return "";
 	if( chk_flg( flg, FLG_MAP_CHR_INVISIBLE ) )
-		return;
+		return "";
 
 	mbr = get_mbr( x, y );
 	mnstr = get_mnstr( x, y );
@@ -476,19 +563,22 @@ void	show_map_hint_chr( long x, long y )
 	}
 
 	if( msg2 == NULL ){
-		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_CHR,
+		sn_printf( buf, SCREEN_WIDTH, MSG_MAP_HINT_FMT_CHR,
 				x, y, mjr, mnr, msg1 );
 	} else {
-		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_CHR_SUB,
+		sn_printf( buf, SCREEN_WIDTH, MSG_MAP_HINT_FMT_CHR_SUB,
 				x, y, mjr, mnr, msg1, msg2 );
 	}
+
+	return buf;
 }
 
 /**/
 
-void	show_map_hint_obj( long x, long y )
+const char	*get_str_map_hint_obj( long x, long y )
 {
-	dun_t	*dun = get_dun();
+	static char	buf[SCREEN_WIDTH * 2 + 1];
+	dun_t	*dun;
 	char	mjr, mnr;
 	flg_map_t	flg;
 	char	*msg1, *msg2;
@@ -497,14 +587,15 @@ void	show_map_hint_obj( long x, long y )
 	door_t	*door;
 
 	if( !clip_pos( x, y ) )
-		return;
+		return "";
 
+	dun = get_dun();
 	mjr = dun->map.obj.mjr[y][x];
 	mnr = dun->map.obj.mnr[y][x];
 	flg = dun->map.obj.flg[y][x];
 
 	if( !chk_flg( flg, FLG_MAP_OBJ_FIND ) )
-		return;
+		return "";
 
 	item = get_item( x, y );
 	trap = get_trap( x, y );
@@ -539,6 +630,10 @@ void	show_map_hint_obj( long x, long y )
 		if( chk_flg( door->flg, FLG_DOOR_SHOP ) ){
 			msg1 = MSG_MAP_HINT_SHOP;
 			msg2 = get_shop_name( get_shop_n( door->mnr ) );
+		} else if( mnr == FACE_MNR_GATE ){
+			msg1 = MSG_MAP_HINT_GATE;
+		} else if( mnr == FACE_MNR_WINDOW ){
+			msg1 = MSG_MAP_HINT_WINDOW;
 		} else {
 			msg1 = MSG_MAP_HINT_DOOR;
 		}
@@ -549,12 +644,14 @@ void	show_map_hint_obj( long x, long y )
 	}
 
 	if( msg2 == NULL ){
-		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_OBJ,
+		sn_printf( buf, SCREEN_WIDTH, MSG_MAP_HINT_FMT_OBJ,
 				x, y, mjr, mnr, msg1 );
 	} else {
-		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_OBJ_SUB,
+		sn_printf( buf, SCREEN_WIDTH, MSG_MAP_HINT_FMT_OBJ_SUB,
 				x, y, mjr, mnr, msg1, msg2 );
 	}
+
+	return buf;
 }
 
 /**/
@@ -625,6 +722,20 @@ long	menu_mbr_data(
 	mbr_t *org_p, long *page_n, data_n_t *data_n,
 	mbr_data_edit_kind_t edit_kind
 )
+{
+	long	res;
+
+	res = menu_mbr_data_sub( org_p, page_n, data_n, edit_kind );
+	call_gui_chr_sheet_wipe();
+	return res;
+}
+
+/**/
+
+long	menu_mbr_data_sub(
+	mbr_t *org_p, long *page_n, data_n_t *data_n,
+	mbr_data_edit_kind_t edit_kind
+)
 {
 	mbr_t	dst_mbr, *mbr_p;
 	data_n_t	prev_n;
@@ -639,6 +750,10 @@ long	menu_mbr_data(
 	*data_n = next_mbr_data( *page_n, *data_n, +-0, edit_kind );
 	prev_n = *data_n;
 
+	g_page_n = page_n;
+	g_data_n = data_n;
+	g_mbr_data_edit_kind = edit_kind;
+
 	draw_mbr_data_all( org_p, mbr_p, *page_n );
 
 	while( 1 ){
@@ -713,11 +828,16 @@ long	menu_mbr_data(
 			exec_menu_edit_mbr_data(
 					mbr_p, *data_n,
 					&mbr_dn, &page_dn );
+
+			if( g_flg_gui )
+				call_gui_menu_wipe();
+			redraw_mbr_data( org_p, mbr_p, *page_n );
 		}
 		if( mbr_dn != 0 ){
 			if( exec_menu_ask_edit_mbr_data( org_p, mbr_p ) )
 				return mbr_dn;
-			draw_mbr_data_all( org_p, mbr_p, *page_n );
+
+			redraw_mbr_data( org_p, mbr_p, *page_n );
 		}
 		if( page_dn != 0 ){
 			*page_n += page_dn;
@@ -730,12 +850,14 @@ long	menu_mbr_data(
 				new_mbr_reset( mbr_p );
 				*org_p = *mbr_p;
 			}
-			draw_mbr_data_all( org_p, mbr_p, *page_n );
+
+			redraw_mbr_data( org_p, mbr_p, *page_n );
 		}
 		if( flg_cancel ){
 			if( exec_menu_ask_edit_mbr_data( org_p, mbr_p ) )
 				return 0;
-			draw_mbr_data_all( org_p, mbr_p, *page_n );
+
+			redraw_mbr_data( org_p, mbr_p, *page_n );
 		}
 	}
 
@@ -744,6 +866,43 @@ long	menu_mbr_data(
 
 /**/
 
+void	set_data_n( data_n_t data_n )
+{
+	if( g_data_n == NULL )
+		return;
+
+	*g_data_n = data_n;
+}
+
+/**/
+
+long	get_mbr_data_page_n( void )
+{
+	if( g_page_n == NULL )
+		return 0;
+
+	return *g_page_n;
+}
+
+/**/
+
+void	set_mbr_data_page_n( long n )
+{
+	if( g_page_n == NULL )
+		return;
+
+	*g_page_n = n;
+}
+
+/**/
+
+mbr_data_edit_kind_t	get_mbr_data_edit_kind( void )
+{
+	return g_mbr_data_edit_kind;
+}
+
+/**/
+
 void	exec_menu_edit_mbr_data(
 	mbr_t *mbr, data_n_t n, long *mbr_dn, long *page_dn
 )
@@ -774,6 +933,9 @@ void	exec_menu_edit_mbr_data(
 	case DATA_N_SEX:
 		exec_menu_sex( &(mbr->sex.cur) );
 		break;
+	case DATA_N_GRAPH_FILE:
+		sel_mbr_graph_file( mbr );
+		break;
 	case DATA_N_CLASS:
 		exec_menu_class( &(mbr->class_n) );
 		break;
@@ -874,6 +1036,21 @@ bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p )
 
 /**/
 
+void	sel_mbr_graph_file( mbr_t *mbr )
+{
+	if( !g_flg_gui ){
+		print_msg( FLG_MSG_WRN, MSG_ERR_CHK_GUI );
+		return;
+	}
+
+	if( call_sel_mbr_graph_begin( mbr ) )
+		get_key_wait_cancel_or_exec( TRUE );
+
+	call_sel_mbr_graph_end();
+}
+
+/**/
+
 char	*menu_sel_mnstr_data( void )
 {
 	pos_t	*crsr = get_crsr();
@@ -1108,12 +1285,13 @@ void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n )
 		if( i == mbr_n )
 			*dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/formation/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/formation/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		sprintf( ls[k].msg, "%ld", i );
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, "%ld", i );
 		ls[k].call_back = cb_menu_formation_sel_n;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
@@ -2595,7 +2773,8 @@ char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt )
 		if( chk_flg( pty->mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
-		sprintf( ls[k].path, "/config member flag/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/config member flag/%ld", i );
 		str_nz_cpy( ls[k].kind, "<CheckItem>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
@@ -2631,7 +2810,7 @@ char	*cb_menu_mbr_flg_init( menu_t **pp, menu_t **dflt )
 		if( chk_flg( pty->mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
-		sprintf( str, "%ld", i );
+		sn_printf( str, 4, "%ld", i );
 		if( chk_flg( pty->mbr[i]->flg_chr, flg ) )
 			set_chk_on_menu( *pp, str );
 		else
@@ -2809,7 +2988,7 @@ char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt )
 	ls = ls_menu_lang_ls;
 	k = 0;
 
-	sprintf( ls[k].path, "/lang" );
+	sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/lang" );
 	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -2820,7 +2999,7 @@ char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	sprintf( ls[k].path, "/lang/title" );
+	sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/lang/title" );
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -2850,7 +3029,8 @@ char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt )
 		if( i == get_lang_kind_next() )
 			*dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/lang/%ld", (long)i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/lang/%ld", (long)i );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A'
 				+ (i % MENU_LANG_LS_N_PER_PAGE));
@@ -3070,7 +3250,8 @@ char	*cb_menu_vfx( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "wait" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_VFX_WAIT, get_vfx_wait() );
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_MENU_VFX_WAIT, get_vfx_wait() );
 
 	/* mbr */
 
@@ -3173,7 +3354,8 @@ char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt )
 	ret = exec_menu_sel_num( &n, VFX_WAIT_MIN_N, VFX_WAIT_MAX_N );
 	if( ret == NULL ){
 		set_vfx_wait( n );
-		sprintf( (*pp)->msg, MSG_MENU_VFX_WAIT, n );
+		sn_printf( (*pp)->msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_VFX_WAIT, n );
 		return STR_MENU_CANCEL;
 	}
 
@@ -3202,7 +3384,7 @@ char	*cb_menu_color( menu_t **pp, menu_t **dflt )
 	ls = ls_menu_color;
 	k = 0;
 
-	sprintf( ls[k].path, "/color" );
+	sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/color" );
 	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -3213,7 +3395,7 @@ char	*cb_menu_color( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	sprintf( ls[k].path, "/color/title" );
+	sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/color/title" );
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -3243,7 +3425,8 @@ char	*cb_menu_color( menu_t **pp, menu_t **dflt )
 			ls[k].flg = FLG_NULL;
 			k++;
 		}
-		sprintf( ls[k].path, "/color/%ld", (long)i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/color/%ld", (long)i );
 		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
@@ -3452,7 +3635,7 @@ char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt )
 	n = get_crsr_ptn_n();
 	max_n = get_crsr_ptn_max_n();
 
-	sprintf( ls[k].path, "/cursor" );
+	sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/cursor" );
 	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -3463,7 +3646,7 @@ char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	sprintf( ls[k].path, "/cursor/title" );
+	sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/cursor/title" );
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -3495,12 +3678,14 @@ char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt )
 		if( i == n )
 			*dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/cursor/%ld", (long)(i + 1) );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/cursor/%ld", (long)(i + 1) );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		sprintf( ls[k].msg, "%ld", (long)(i + 1) );
+		sn_printf( ls[k].msg, MENU_PATH_MAX_LEN,
+				"%ld", (long)(i + 1) );
 		ls[k].call_back = cb_menu_crsr_ptn_sel;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
@@ -3636,7 +3821,8 @@ char	*cb_menu_set_key( menu_t **pp, menu_t **dflt )
 		str_nz_cpy( buf_cmd, prev_cmd, MACRO_MAX_LEN );
 	}
 
-	sprintf( msg_cmd, MSG_GETS_SET_KEY_CMD, MACRO_MAX_LEN );
+	sn_printf( msg_cmd, WIN_MSG_DRAW_WIDTH,
+			MSG_GETS_SET_KEY_CMD, MACRO_MAX_LEN );
 	print_msg( FLG_NULL, msg_cmd );
 
 	x = str_len_draw( msg_cmd );
@@ -3788,7 +3974,6 @@ char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt )
 			break;
 		if( strcmp( str, "0" ) == 0 )
 			break;
-
 		if( strcmp( str, "." ) == 0 ){
 			str = "0";
 			break;
@@ -3816,7 +4001,7 @@ char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt )
 	y = get_max_line() - 1;
 	n = (long)((*pp)->arg);
 
-	sprintf( msg, MSG_GETS_FUNC_EDIT, MACRO_MAX_LEN );
+	sn_printf( msg, 80, MSG_GETS_FUNC_EDIT, MACRO_MAX_LEN );
 	print_msg( FLG_NULL, MSG_GETS_FUNC_PREV, get_func( n ) );
 	print_msg( FLG_NULL, msg );
 
@@ -3849,7 +4034,8 @@ char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt )
 
 	n = (long)((*pp)->arg);
 
-	sprintf( msg, MSG_TTL_MENU_FUNC_SET_REG_MACRO, n );
+	sn_printf( msg, WIN_MSG_DRAW_WIDTH,
+			MSG_TTL_MENU_FUNC_SET_REG_MACRO, n );
 
 	print_msg( FLG_NULL, MSG_GETS_FUNC_PREV, get_func( n ) );
 	print_msg( FLG_NULL, msg );
@@ -3929,7 +4115,8 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 			k++;
 		}
 
-		sprintf( ls[k].path, "/user menu/%ld", k );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/user menu/%ld", k );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
@@ -3946,7 +4133,7 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 			MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<OpenWinItem>",
 			MENU_KIND_MAX_LEN );
-	ls[k].accel_key = 'V';
+	ls[k].accel_key = 'T';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	str_nz_cpy( ls[k].msg, MSG_MENU_USER_NEW, MENU_MSG_MAX_LEN );
@@ -3959,7 +4146,7 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 			MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<OpenWinItem>",
 			MENU_KIND_MAX_LEN );
-	ls[k].accel_key = 'W';
+	ls[k].accel_key = 'U';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	str_nz_cpy( ls[k].msg, MSG_MENU_USER_NEW_REG_MACRO,
@@ -3969,6 +4156,32 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
+	str_nz_cpy( ls[k].path, "/user menu/arrange up",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>",
+			MENU_KIND_MAX_LEN );
+	ls[k].accel_key = 'V';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	str_nz_cpy( ls[k].msg, MSG_MENU_USER_ARRANGE_UP, MENU_MSG_MAX_LEN );
+	ls[k].call_back = cb_menu_user_arrange_up;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	str_nz_cpy( ls[k].path, "/user menu/arrange down",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>",
+			MENU_KIND_MAX_LEN );
+	ls[k].accel_key = 'W';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	str_nz_cpy( ls[k].msg, MSG_MENU_USER_ARRANGE_DOWN, MENU_MSG_MAX_LEN );
+	ls[k].call_back = cb_menu_user_arrange_down;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
 	str_nz_cpy( ls[k].path, "/user menu/arrange top",
 			MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<Branch>",
@@ -4130,7 +4343,8 @@ char	*menu_user_new_sub(
 	} else {
 		long	len;
 
-		sprintf( msg_cmd, MSG_GETS_USER_MENU_CMD, MACRO_MAX_LEN );
+		sn_printf( msg_cmd, WIN_MSG_DRAW_WIDTH,
+				MSG_GETS_USER_MENU_CMD, MACRO_MAX_LEN );
 		print_msg( FLG_NULL, MSG_S, msg_cmd );
 
 		x = str_len_draw( msg_cmd );
@@ -4161,6 +4375,34 @@ char	*menu_user_new_sub(
 
 /**/
 
+char	*cb_menu_user_arrange_up( menu_t **pp, menu_t **dflt )
+{
+	menu_t	*ls = ls_menu_user_edit;
+
+	set_edit_user_menu( ls, cb_menu_user_arrange_up_sel,
+			MSG_MENU_USER_ARRANGE_UP );
+
+	exec_menu( ls, NULL, NULL );
+
+	return "/misc/config/user menu select";
+}
+
+/**/
+
+char	*cb_menu_user_arrange_down( menu_t **pp, menu_t **dflt )
+{
+	menu_t	*ls = ls_menu_user_edit;
+
+	set_edit_user_menu( ls, cb_menu_user_arrange_down_sel,
+			MSG_MENU_USER_ARRANGE_DOWN );
+
+	exec_menu( ls, NULL, NULL );
+
+	return "/misc/config/user menu select";
+}
+
+/**/
+
 char	*cb_menu_user_arrange_top( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls = ls_menu_user_edit;
@@ -4257,7 +4499,8 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl )
 			k++;
 		}
 
-		sprintf( ls[k].path, "/user menu edit/%ld", k );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/user menu edit/%ld", k );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
@@ -4275,11 +4518,51 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl )
 
 /**/
 
+char	*cb_menu_user_arrange_up_sel( menu_t **pp, menu_t **dflt )
+{
+	return arrange_menu_user_1( (long)((*pp)->arg), -1 );
+}
+
+/**/
+
+char	*cb_menu_user_arrange_down_sel( menu_t **pp, menu_t **dflt )
+{
+	return arrange_menu_user_1( (long)((*pp)->arg), +1 );
+}
+
+/**/
+
+char	*arrange_menu_user_1( long n, long d )
+{
+	char	name[MENU_MSG_MAX_LEN + 1];
+	char	cmd[MACRO_MAX_LEN + 1];
+
+	if( (n + d) < 0 )
+		return NULL;
+	if( (n + d) >= g_user_menu_n )
+		return NULL;
+
+	str_nz_cpy( name, g_user_menu_name[n], MENU_MSG_MAX_LEN );
+	str_nz_cpy( cmd, g_user_menu_cmd[n], MACRO_MAX_LEN );
+
+	str_nz_cpy( g_user_menu_name[n], g_user_menu_name[n + d],
+			MENU_MSG_MAX_LEN );
+	str_nz_cpy( g_user_menu_cmd[n], g_user_menu_cmd[n + d],
+			MACRO_MAX_LEN );
+
+	str_nz_cpy( g_user_menu_name[n + d], name, MENU_MSG_MAX_LEN );
+	str_nz_cpy( g_user_menu_cmd[n + d], cmd, MACRO_MAX_LEN );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt )
 {
 	long	i, n;
 	char	name[MENU_MSG_MAX_LEN + 1];
-	char	cmd[MENU_MSG_MAX_LEN + 1];
+	char	cmd[MACRO_MAX_LEN + 1];
 
 	n = (long)((*pp)->arg);
 
@@ -4307,7 +4590,7 @@ char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt )
 {
 	long	i, n;
 	char	name[MENU_MSG_MAX_LEN + 1];
-	char	cmd[MENU_MSG_MAX_LEN + 1];
+	char	cmd[MACRO_MAX_LEN + 1];
 
 	n = (long)((*pp)->arg);
 
@@ -4499,7 +4782,8 @@ long	menu_replay_sel_load( void )
 			k++;
 		}
 
-		sprintf( ls[k].path, "/replay load list/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/replay load list/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
@@ -4591,18 +4875,21 @@ char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt )
+char	*cb_menu_wizard_add_turn_hour( menu_t **pp, menu_t **dflt )
 {
-	const long	n = 1 * TURN_A_DAY;
-	static long	turn = 0;
+	const long	max_n = 24;
+	long	n, turn;
 	char	*str;
 
-	str = exec_menu_sel_num( &turn, -n, +n );
+	n = static_cb_menu_wizard_add_turn__hour;
+
+	str = exec_menu_sel_num( &n, 0, max_n );
 	if( str != NULL )
 		return str;
 
 	set_flg_no_save( TRUE );
 
+	turn = n * TURN_PER_HOUR;
 	reset_turn( get_turn() + turn );
 
 	return STR_MENU_CANCEL;
@@ -4610,15 +4897,61 @@ char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt )
+char	*cb_menu_wizard_add_turn_minute( menu_t **pp, menu_t **dflt )
+{
+	const long	max_n = 60;
+	long	n, turn;
+	char	*str;
+
+	n = static_cb_menu_wizard_add_turn__minute;
+
+	str = exec_menu_sel_num( &n, 0, max_n );
+	if( str != NULL )
+		return str;
+
+	set_flg_no_save( TRUE );
+
+	turn = n * TURN_PER_MINUTE;
+	reset_turn( get_turn() + turn );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_wizard_add_turn_turn( menu_t **pp, menu_t **dflt )
+{
+	const long	max_n = TURN_A_DAY;
+	long	n, turn;
+	char	*str;
+
+	n = static_cb_menu_wizard_add_turn__turn;
+
+	str = exec_menu_sel_num( &n, 0, max_n );
+	if( str != NULL )
+		return str;
+
+	set_flg_no_save( TRUE );
+
+	turn = n;
+	reset_turn( get_turn() + turn );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_wizard_up_exp( menu_t **pp, menu_t **dflt )
 {
 	party_t	*pty = get_party();
 	pet_t	**pet = get_party_pet();
 	const long	n = EXP_MAX;
-	static long	exp = +(100 * 100 * 100);
+	long	exp = +(100 * 100 * 100);
 	char	*str;
 	long	i;
 
+	exp = static_cb_menu_wizard_up_exp__exp = +(100 * 100 * 100);
+
 	str = exec_menu_sel_num( &exp, -n, +n );
 	if( str != NULL )
 		return str;
@@ -4652,6 +4985,93 @@ char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_wizard_up_lev( menu_t **pp, menu_t **dflt )
+{
+	mbr_t	*mbr;
+	abl_kind_t	abl;
+	long	lev, min_lev, max_lev;
+	long	need_exp;
+	char	*str;
+
+	mbr = NULL;
+
+	while( 1 ){
+		/* СڥåȤ */
+
+		str = exec_menu_sel_mbr(
+				&mbr, MSG_MENU_CRSR_MOVE_MBR,
+				FALSE, TRUE );
+		if( str != NULL ){
+			if( strcmp( str, STR_MENU_CANCEL ) == 0 ){
+				break;
+			} else {
+				return str;
+			}
+		}
+		if( mbr == NULL )
+			return STR_MENU_ERR;
+
+		while( 1 ){
+			/* ǽͤ */
+
+			str = exec_menu_sel_abl( mbr, &abl );
+			if( str != NULL ){
+				if( strcmp( str, STR_MENU_CANCEL ) == 0 ){
+					break;
+				} else {
+					return str;
+				}
+			}
+
+			lev = mbr->abl.lev[abl].n;
+			max_lev = ABL_MAX_LEV;
+			if( (ABL_KIND_HP <= abl) && (abl <= ABL_KIND_CHA) )
+				min_lev = 1;
+			else
+				min_lev = 0;
+
+			/* ǽͤΥ٥ */
+
+			str = exec_menu_sel_num( &lev, min_lev, max_lev );
+			if( str != NULL ){
+				if( strcmp( str, STR_MENU_CANCEL ) == 0 ){
+					continue;
+				} else {
+					return str;
+				}
+			}
+
+			/* ǽͤΥ٥ */
+
+			need_exp = calc_need_exp( lev, abl );
+			mbr->abl.exp[abl].n = need_exp;
+			chk_lev_up( mbr, TRUE, FALSE );
+		}
+	}
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_wizard_scene( menu_t **pp, menu_t **dflt )
+{
+	scene_n_t	sc;
+
+	sc = (scene_n_t)((*pp)->arg);
+
+	if( sc == SCENE_N_GAME_OVER )
+		game_over();
+	else if( sc == SCENE_N_ENDING )
+		ending();
+	else
+		change_scene( sc );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_out_map_file( menu_t **pp, menu_t **dflt )
 {
 	if( out_map_file() )
@@ -4673,7 +5093,7 @@ char	*cb_menu_shell( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_about_game( menu_t **pp, menu_t **dflt )
 {
-	about_game();
+	about_game( FALSE );
 
 	return NULL;
 }
