@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.77 2008/05/07 07:31:26 bowkenken Exp $
+* $Id: inc.h,v 1.100 2008/09/19 21:15:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -96,7 +96,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
-/*#include	"scene.h"*/
+#include	"scene.h"
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -120,7 +120,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
-/*#include	"scene-prot.h"*/
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -275,6 +275,8 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#include	"call-prot.h"
+
 #endif	/* REPLAY_C */
 
 /***************************************************************/
@@ -353,7 +355,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
-/*#include	"scene.h"*/
+#include	"scene.h"
 /*#include	"turn.h"*/
 #include	"dun.h"
 #include	"town.h"
@@ -377,7 +379,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
-/*#include	"scene-prot.h"*/
+#include	"scene-prot.h"
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -654,13 +656,13 @@
 
 #include	<signal.h>
 
-#if	HAVE_GETOPT_H
+#ifdef	HAVE_GETOPT_H
 # include	<getopt.h>
 #endif
 
-#if	HAVE_TERMIOS_H
+#if	defined( HAVE_TERMIOS_H )
 # include	<termios.h>
-#elif	HAVE_TERMIO_H
+#elif	defined( HAVE_TERMIO_H )
 # include	<termio.h>
 #endif
 
@@ -689,7 +691,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
-/*#include	"scene.h"*/
+#include	"scene.h"
 #include	"turn.h"
 #include	"dun.h"
 #include	"town.h"
@@ -713,7 +715,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
-/*#include	"scene-prot.h"*/
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1038,6 +1040,10 @@
 /*#include	"gfile-prot.h"*/
 #include	"msg-prot.h"
 
+# ifdef D_GTK
+#  include <gtk/gtk.h>
+# endif /* D_GTK */
+
 #endif	/* MISC_C */
 
 /***************************************************************/
@@ -1046,7 +1052,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
-/*#include	"scene.h"*/
+#include	"scene.h"
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1070,7 +1076,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
-/*#include	"scene-prot.h"*/
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1556,6 +1562,9 @@
 #include	"gfile-prot.h"
 /*#include	"msg-prot.h"*/
 
+#include	"music-kind.h"
+#include	"call-prot.h"
+
 #endif	/* TMENU_C */
 
 /***************************************************************/
@@ -1564,7 +1573,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
-/*#include	"scene.h"*/
+#include	"scene.h"
 #include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
@@ -1588,7 +1597,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
-/*#include	"scene-prot.h"*/
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
@@ -1734,22 +1743,22 @@
 #ifdef	SCENE_C
 
 #include	"gmain.h"
-/*#include	"misc.h"*/
+#include	"misc.h"
 #include	"scene.h"
 /*#include	"turn.h"*/
-/*#include	"dun.h"*/
+#include	"dun.h"
 /*#include	"town.h"*/
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
+#include	"chr.h"
+#include	"party.h"
+#include	"mnstr.h"
 /*#include	"pet.h"*/
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
 /*#include	"trap.h"*/
 /*#include	"replay.h"*/
-/*#include	"draw.h"*/
+#include	"draw.h"
 /*#include	"curs.h"*/
 /*#include	"menu.h"*/
 /*#include	"amenu.h"*/
@@ -1758,16 +1767,16 @@
 /*#include	"msg.h"*/
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
-/*#include	"misc-prot.h"*/
+#include	"misc-prot.h"
 #include	"scene-prot.h"
 /*#include	"turn-prot.h"*/
-/*#include	"dun-prot.h"*/
+#include	"dun-prot.h"
 /*#include	"town-prot.h"*/
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
-/*#include	"chr-prot.h"*/
-/*#include	"party-prot.h"*/
-/*#include	"mnstr-prot.h"*/
+#include	"chr-prot.h"
+#include	"party-prot.h"
+#include	"mnstr-prot.h"
 /*#include	"pet-prot.h"*/
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
@@ -1784,6 +1793,8 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"call-prot.h"
+
 #endif	/* SCENE_C */
 
 /***************************************************************
@@ -2006,6 +2017,7 @@
 #  include "SelMbrGraph.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
+#  include "misc-prot.h"
 #  include "chr-prot.h"
 #  include "draw-prot.h"
 # elif	defined( D_GTK )
@@ -2020,8 +2032,10 @@
 #  include "SelMbrGraph.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
+#  include "misc-prot.h"
 #  include "chr-prot.h"
 #  include "draw-prot.h"
+#  include "main-gtk-prot.h"
 # elif	defined( D_MFC )
 #  include "gmain.h"
 #  include "misc.h"
@@ -2034,6 +2048,7 @@
 #  include "SelMbrGraph.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
+#  include "misc-prot.h"
 #  include "chr-prot.h"
 #  include "draw-prot.h"
 # else
@@ -2041,6 +2056,7 @@
 #  include "misc.h"
 #  include "chr.h"
 #  include "draw.h"
+#  include "misc-prot.h"
 #  include "chr-prot.h"
 # endif
 
@@ -2141,6 +2157,355 @@
 
 /***************************************************************/
 
+#ifdef	DEMO_TITLE_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+/*#include	"draw.h"*/
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+#include	"msg-prot.h"
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+#endif // D_MFC
+
+#include "DemoTitle.h"
+#include "GlobalVar.h"
+
+#endif	/* DEMO_TITLE_CPP */
+
+/***************************************************************/
+
+#ifdef	DEMO_GAME_OVER_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+/*#include	"draw.h"*/
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+#include	"msg-prot.h"
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+#endif // D_MFC
+
+#include "DemoGameOver.h"
+#include "GlobalVar.h"
+
+#endif	/* DEMO_GAME_OVER_CPP */
+
+/***************************************************************/
+
+#ifdef	DEMO_ENDING_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+/*#include	"draw.h"*/
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+#include	"msg-prot.h"
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+#endif // D_MFC
+
+#include "DemoEnding.h"
+#include "GlobalVar.h"
+
+#endif	/* DEMO_ENDING_CPP */
+
+/***************************************************************/
+
+#ifdef	DEMO_SPACE_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+/*#include	"draw.h"*/
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+#include	"msg-prot.h"
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+#endif // D_MFC
+
+#include "DemoSpace.h"
+#include "GlobalVar.h"
+
+#endif	/* DEMO_SPACE_CPP */
+
+/***************************************************************/
+
+#ifdef	GAME_MUSIC_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+#include	"dun.h"
+#include	"town.h"
+#include	"item.h"
+/*#include	"spell.h"*/
+#include	"chr.h"
+#include	"party.h"
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+#include	"dun-prot.h"
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+#include	"tmenu-prot.h"
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+#include	"msg-prot.h"
+
+#include "FileList.h"
+#include "GameMusic.h"
+#include "GlobalVar.h"
+
+#endif	/* GAME_MUSIC_CPP */
+
+/***************************************************************/
+
 #ifdef	GUI_MESSAGE_CPP
 
 #include	"gmain.h"
@@ -2273,7 +2638,7 @@
 #include "GlobalVar.h"
 
 #ifdef D_GTK
-#include "main-gtk-prot.h"
+# include "main-gtk-prot.h"
 #endif /* D_GTK */
 
 #endif	/* GUI_STAT_CPP */
@@ -2425,6 +2790,315 @@
 
 /***************************************************************/
 
+#ifdef	GUI_WORDS_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GuiMisc.h"
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/WordsDlg.h"
+# include "MfcWSCstring.h"
+#endif // D_MFC
+
+#include "GuiWords.h"
+#include "GlobalVar.h"
+
+#ifdef D_GTK
+# include "main-gtk-prot.h"
+#endif /* D_GTK */
+
+#endif	/* GUI_WORDS_CPP */
+
+/***************************************************************/
+
+#ifdef	GUI_REPLAY_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"replay.h"
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"replay-prot.h"
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GuiMisc.h"
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/ReplayWnd.h"
+#endif // D_MFC
+
+#include "GuiReplay.h"
+#include "GlobalVar.h"
+
+#ifdef D_GTK
+# include "main-gtk-prot.h"
+#endif /* D_GTK */
+
+#endif	/* GUI_REPLAY_CPP */
+
+/***************************************************************/
+
+#ifdef	GUI_CLASS_EDIT_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+#include	"town.h"
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+#include	"chr.h"
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+#include	"chr-prot.h"
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+#include	"tmenu-prot.h"
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GuiMisc.h"
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/ClassEditDlg.h"
+#endif // D_MFC
+
+#include "GuiClassEdit.h"
+#include "GlobalVar.h"
+
+#ifdef D_GTK
+# include "main-gtk-prot.h"
+#endif /* D_GTK */
+
+#endif	/* GUI_CLASS_EDIT_CPP */
+
+/***************************************************************/
+
+#ifdef	GUI_CHR_SHEET_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+#include	"turn.h"
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+#include	"item.h"
+/*#include	"spell.h"*/
+#include	"chr.h"
+#include	"party.h"
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+#include	"fight.h"
+#include	"fx.h"
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+#include	"turn-prot.h"
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+#include	"item-prot.h"
+/*#include	"spell-prot.h"*/
+#include	"chr-prot.h"
+#include	"party-prot.h"
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+#include	"fight-prot.h"
+#include	"fx-prot.h"
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GuiMisc.h"
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/ChrSheetSheet.h"
+#endif // D_MFC
+
+#include "GuiChrSheet.h"
+#include "GlobalVar.h"
+
+#endif	/* GUI_CHR_SHEET_CPP */
+
+/***************************************************************/
+
 #if 0
 #if	defined( D_WS )
 # include	"main-ws-prot.h"
