@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.89 2007/03/11 20:27:12 bowkenken Exp $
+* $Id: item.h,v 1.92 2008/05/18 19:24:34 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
@@ -543,6 +543,8 @@ typedef enum {
 	SCROLL_KIND_INUNDATION,
 	SCROLL_KIND_SUBSTITUTE,
 	SCROLL_KIND_BURNING_HANDS,
+	SCROLL_KIND_RALLY,
+	SCROLL_KIND_IRON_MAN,
 	SCROLL_KIND_MIND_READING,
 	SCROLL_KIND_MAX_N,
 } scroll_kind_t;
@@ -975,6 +977,9 @@ typedef struct {
 typedef struct {
 	light_kind_t	kind;
 	long	turn;
+	wish_level_t	wish_level;
+	long	wish_n;
+	bool_t	flg_used;
 } light_t;
 
 typedef struct {
@@ -1264,6 +1269,9 @@ typedef struct {
 	/* ̾ */
 	char	*name;
 	n_msg_t	name_n;
+	/* ̸̾ */
+	char	*i_name;
+	n_msg_t	i_name_n;
 
 	/*  */
 	light_kind_t	kind;
@@ -1281,6 +1289,11 @@ typedef struct {
 	long	max_turn;
 	/* ǽե饰 */
 	bool_t	flg_fill;
+
+	/* ˡΥפμ */
+	wish_level_t	wish_level;
+	/* ˡΥפκѲ */
+	long	wish_max_n;
 } light_tab_t;
 
 typedef struct {
@@ -1426,6 +1439,7 @@ typedef struct {
 	inst_kind_t	inst;
 	anthology_kind_t	anthology;
 	light_kind_t	light;
+	wish_level_t	wish_level;
 	food_kind_t	food;
 	item_kind_dat_tobacco_t	tobacco;
 	pipe_kind_t	pipe;
