@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.199 2007/12/15 08:18:28 bowkenken Exp $
+* $Id: menu.c,v 1.209 2008/09/07 11:31:27 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -39,6 +39,7 @@
 
 static long	g_nest_flg_executing_menu;
 static bool_t	g_flg_space_select;
+static bool_t	g_flg_menu_dflt;
 static bool_t	g_flg_chk_menu;
 static bool_t	g_flg_chk_short_key;
 
@@ -94,6 +95,7 @@ static func_short_key_t
 		g_ls_func_short_key[FUNC_KEY_MAX + 1] = {
 	{ NULL, NULL },	/* NULL */
 
+/* ե󥯥󡦥 */
 	{ NULL, NULL },	/* F1 */
 	{ NULL, NULL },	/* F2 */
 	{ NULL, NULL },	/* F3 */
@@ -115,8 +117,9 @@ static func_short_key_t
 	{ NULL, NULL },	/* F19 */
 	{ NULL, NULL },	/* F20 */
 
-	{ NULL, "\n" },	/* F21 */
-	{ NULL, "+" },	/* F22 */
+/* ޥå */
+	{ NULL, "+" },	/* F21 */
+	{ NULL, NULL },	/* F22 */
 	{ NULL, "." },	/* F23 */
 	{ NULL, NULL },	/* F24 */
 	{ NULL, NULL },	/* F25 */
@@ -126,8 +129,9 @@ static func_short_key_t
 	{ NULL, NULL },	/* F29 */
 	{ NULL, NULL },	/* F30 */
 
-	{ NULL, "," },	/* F31 */
-	{ NULL, "+" },	/* F32 */
+/* ޥ֥롦å */
+	{ NULL, "\n" },	/* F31 */
+	{ NULL, NULL },	/* F32 */
 	{ NULL, NULL },	/* F33 */
 	{ NULL, NULL },	/* F34 */
 	{ NULL, NULL },	/* F35 */
@@ -137,16 +141,51 @@ static func_short_key_t
 	{ NULL, NULL },	/* F39 */
 	{ NULL, NULL },	/* F40 */
 
-	{ NULL, "/" },	/* F41 */
-	{ NULL, "*" },	/* F42 */
-	{ NULL, "-" },	/* F43 */
-	{ NULL, "+" },	/* F44 */
+/* ޥξå */
+	{ NULL, "+" },	/* F41 */
+	{ NULL, "," },	/* F42 */
+	{ NULL, NULL },	/* F43 */
+	{ NULL, NULL },	/* F44 */
 	{ NULL, NULL },	/* F45 */
 	{ NULL, NULL },	/* F46 */
 	{ NULL, NULL },	/* F47 */
 	{ NULL, NULL },	/* F48 */
 	{ NULL, NULL },	/* F49 */
 	{ NULL, NULL },	/* F50 */
+
+/* ޥץ쥹 */
+	{ NULL, NULL },	/* F51 */
+	{ NULL, NULL },	/* F52 */
+	{ NULL, "," },	/* F53 */
+	{ NULL, NULL },	/* F54 */
+	{ NULL, NULL },	/* F55 */
+	{ NULL, NULL },	/* F56 */
+	{ NULL, NULL },	/* F57 */
+	{ NULL, NULL },	/* F58 */
+	{ NULL, NULL },	/* F59 */
+	{ NULL, NULL },	/* F60 */
+/* ޥ꡼ */
+	{ NULL, NULL },	/* F61 */
+	{ NULL, NULL },	/* F62 */
+	{ NULL, "0" },	/* F63 */
+	{ NULL, NULL },	/* F64 */
+	{ NULL, NULL },	/* F65 */
+	{ NULL, NULL },	/* F66 */
+	{ NULL, NULL },	/* F67 */
+	{ NULL, NULL },	/* F68 */
+	{ NULL, NULL },	/* F69 */
+	{ NULL, NULL },	/* F70 */
+/* ޥ⡼ */
+	{ NULL, "/" },	/* F71 */
+	{ NULL, "*" },	/* F72 */
+	{ NULL, "-" },	/* F73 */
+	{ NULL, "+" },	/* F74 */
+	{ NULL, NULL },	/* F75 */
+	{ NULL, NULL },	/* F76 */
+	{ NULL, NULL },	/* F77 */
+	{ NULL, NULL },	/* F78 */
+	{ NULL, NULL },	/* F79 */
+	{ NULL, NULL },	/* F80 */
 };
 
 static bool_t	g_flg_dup_short_key[256];
@@ -162,6 +201,7 @@ void	init_var_menu( void )
 	g_nest_flg_executing_menu = make_nest_flg();
 
 	set_flg_space_select( FALSE );
+	set_flg_menu_dflt( TRUE );
 }
 
 /**/
@@ -188,6 +228,14 @@ void	init_menu( void )
 	init_ls_menu_func();
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_menu( void )
+{
+}
+
 /**/
 
 void	init_ls_menu_func( void )
@@ -241,33 +289,40 @@ void	init_ls_menu_func( void )
 			key = 'A';
 		}
 
-		sprintf( ls[k].path, "/func/%ld", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld", fn );
 		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
-		sprintf( ls[k].msg, MSG_MENU_FUNC_KEY, fn );
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_FUNC_KEY, fn );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/func/%ld/--", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/--", fn );
 		str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
-		sprintf( ls[k].msg, MSG_MENU_FUNC_KEY, fn );
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_FUNC_KEY, fn );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/func/%ld/exec", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/exec", fn );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'X';
 		if( g_ls_func_short_key[fn].key == NULL ){
-			sprintf( ls[k].short_key, "&%02ld", fn );
+			sn_printf( ls[k].short_key, MENU_SHORT_KEY_MAX_LEN,
+					"&%02ld", fn );
 		} else {
-			sprintf( ls[k].short_key, "%s &%02ld",
+			sn_printf( ls[k].short_key, MENU_SHORT_KEY_MAX_LEN,
+					"%s &%02ld",
 					g_ls_func_short_key[i].key, fn );
 		}
 		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_EXEC, MENU_MSG_MAX_LEN );
@@ -276,7 +331,8 @@ void	init_ls_menu_func( void )
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/func/%ld/edit", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/edit", fn );
 		str_nz_cpy( ls[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'E';
 		ls[k].short_key[0] = '\0';
@@ -286,7 +342,8 @@ void	init_ls_menu_func( void )
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/func/%ld/set reg macro", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/set reg macro", fn );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'M';
 		ls[k].short_key[0] = '\0';
@@ -332,6 +389,9 @@ char	*exec_menu_sub( menu_t *p, menu_t *dflt, char *str_goto )
 	if( p == NULL )
 		return STR_MENU_ERR;
 
+	if( !get_flg_menu_dflt() )
+		dflt = NULL;
+
 	chk_err_menu_kind( p );
 
 	/* ˥塼ΥѥȰפ鸡⡼ɽλ */
@@ -349,6 +409,8 @@ char	*exec_menu_sub( menu_t *p, menu_t *dflt, char *str_goto )
 		char	*str_goto_call_back;
 
 		str_goto_call_back = p->call_back( &p, &dflt );
+		if( !get_flg_menu_dflt() )
+			dflt = NULL;
 
 		if( str_goto_call_back != NULL )
 			return str_goto_call_back;
@@ -420,6 +482,28 @@ char	*exec_menu_sub( menu_t *p, menu_t *dflt, char *str_goto )
 	return STR_MENU_ERR;
 }
 
+/***************************************************************
+* ˥塼Υǥեȹܤ̵ͭ
+* return : ͭ?
+***************************************************************/
+
+void	set_flg_menu_dflt( bool_t flg )
+{
+	g_flg_menu_dflt = flg;
+}
+
+/**/
+
+/***************************************************************
+* ˥塼Υǥեȹܤͭ?
+* return : ͭ?
+***************************************************************/
+
+bool_t	get_flg_menu_dflt( void )
+{
+	return g_flg_menu_dflt;
+}
+
 /**/
 
 bool_t	chk_err_menu_kind( menu_t *ls )
@@ -634,7 +718,7 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 		bool_t	flg_ret;
 		char	key;
 
-		sprintf( num, fmt, (int)(figure + 1), n );
+		sn_printf( num, FIGURE_MAX_N, fmt, (int)(figure + 1), n );
 
 		draw_menu_num( figure, sel_n, num );
 
@@ -1296,7 +1380,7 @@ long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu )
 		}
 		break;
 
-#if	HAVE_LIBCURSES
+#ifdef	HAVE_LIBCURSES
 	case KEY_RESIZE:
 		redraw_all();
 		break;
@@ -1332,7 +1416,7 @@ long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu )
 	}
 
 	if( chk_redraw_every_turn() )
-		force_redraw_map();
+		force_clr_redraw_map();
 
 	if( g_flg_echo_key ){
 		if( (c != '\0') && (c != -1) ){
@@ -1414,12 +1498,12 @@ bool_t	chk_dup_short_key_main( menu_t *ls )
 bool_t	chk_dup_short_key_sub( unsigned char c, menu_t *ls )
 {
 	if( g_flg_dup_short_key[c] ){
-		char	s[8];
+		char	s[8 + 1];
 
 		if( ('A' - '@' <= c) && (c <= 'Z' - '@') )
-			sprintf( s, "^%c", c + '@' );
+			sn_printf( s, 8, "^%c", c + '@' );
 		else
-			sprintf( s, "%c", c );
+			sn_printf( s, 8, "%c", c );
 
 		print_err( MSG_ERR_MENU_SHORT_CUT_KEY,
 				s, MSG( ls->n_msg ) );
