@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.36 2008/04/25 23:46:01 bowkenken Exp $
+* $Id: mmenu.c,v 1.42 2008/08/10 23:42:52 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -43,6 +43,7 @@ static pos_t	g_sub_crsr, g_pre_sub_crsr;
 static menu_t	*g_menu_dflt_main;
 
 static chr_t	*g_sub_sel_mbr;
+static abl_kind_t	g_sel_abl;
 static race_t	g_sel_race;
 static sex_t	g_sel_sex;
 static long	g_sel_class_n;
@@ -182,7 +183,8 @@ char	*exec_menu_sel_mbr(
 		if( *mbr == pty->mbr[i] )
 			dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/member/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/member/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
@@ -209,7 +211,8 @@ char	*exec_menu_sel_mbr(
 		if( *mbr == pet[i] )
 			dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/member/%ld", MBR_MAX_N + i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/member/%ld", MBR_MAX_N + i );
 		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + MBR_MAX_N + i);
@@ -247,6 +250,118 @@ char	*cb_menu_sel_mbr( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*exec_menu_sel_abl( mbr_t *mbr, abl_kind_t *abl )
+{
+	menu_t	*ls;
+	menu_t	*dflt;
+	char	key;
+	long	i, k;
+	char	*ret;
+
+	if( abl == NULL )
+		return STR_MENU_ERR;
+
+	if( chk_flg( mbr->stat, FLG_STAT_NOT_EXIST ) )
+		mbr = NULL;
+
+	dflt = NULL;
+
+	ls = ls_menu_abl;
+	k = 0;
+
+	str_nz_cpy( ls[k].path, "/ability",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>",
+			MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	str_nz_cpy( ls[k].path, "/ability/--",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>",
+			MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_SEL_ABL,
+			MENU_MSG_MAX_LEN );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	key = 'A';
+
+	for( i = ABL_KIND_HP; i < ABL_KIND_MAX_N; i++ ){
+		if( i == *abl )
+			dflt = &(ls[k]);
+
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/ability/%ld", i );
+		str_nz_cpy( ls[k].kind, "<Item>",
+				MENU_KIND_MAX_LEN );
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
+		if( mbr == NULL ){
+			str_nz_cpy( ls[k].msg, get_abl_name( (abl_kind_t)i ),
+					MENU_MSG_MAX_LEN );
+		} else {
+			sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+					"%-3s: %ld",
+					get_abl_name( (abl_kind_t)i ),
+					mbr->abl.lev[i].n );
+		}
+		ls[k].call_back = cb_menu_sel_abl;
+		ls[k].arg = (void *)i;
+		ls[k].flg = FLG_NULL;
+		k++;
+
+		key++;
+		if( (i == ABL_KIND_CHA) || (key >= (char)('A' + 12)) ){
+			key = 'A';
+
+			str_nz_cpy( ls[k].path, "/ability/--",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			ls[k].msg[0] = '\0';
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+	}
+
+	ls[k].path[0] = '\0';
+
+	g_sel_abl = ABL_KIND_HP;
+	ret = exec_menu( ls, dflt, NULL );
+	if( ret != NULL )
+		return ret;
+
+	*abl = g_sel_abl;
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_sel_abl( menu_t **pp, menu_t **dflt )
+{
+	g_sel_abl = (abl_kind_t)(int)((*pp)->arg);
+
+	return NULL;
+}
+
+/**/
+
 char	*exec_menu_point_crsr( void )
 {
 	chk_scroll( FALSE );
@@ -387,7 +502,7 @@ char	*exec_menu_class( long *class_n )
 		if( i == *class_n )
 			dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/class/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/class/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + (i % LS_CLASS_N_PER_PAGE));
 		ls[k].short_key[0] = '\0';
@@ -1363,14 +1478,16 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 				if( p == item )
 					break;
 
-				sprintf( ls[k].path, "/item/%ld%c",
+				sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+						"/item/%ld%c",
 						i, (char)('A' + j) );
 				str_nz_cpy( ls[k].kind, "<Branch>",
 						MENU_KIND_MAX_LEN );
 				ls[k].accel_key = (char)('A' + j);
 				ls[k].short_key[0] = '\0';
 				ls[k].n_msg = N_MSG_NULL;
-				sprintf( ls[k].msg, " %s", p->name );
+				sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+						" %s", p->name );
 				ls[k].call_back = cb_menu_item_sel;
 				ls[k].arg = NULL;
 				ls[k].flg = FLG_NULL;
@@ -1378,7 +1495,8 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 			}
 		}
 
-		sprintf( ls[k].path, "/item/%ld%s", i, "equip" );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/item/%ld%s", i, "equip" );
 		str_nz_cpy( ls[k].kind, "<Branch>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'Z';
@@ -1538,7 +1656,10 @@ char	*cb_menu_item_sel_init( menu_t **pp, menu_t **dflt )
 	case ITEM_KIND_ACCE:
 	case ITEM_KIND_INST:
 	case ITEM_KIND_ANTHOLOGY:
+		break;
 	case ITEM_KIND_LIGHT:
+		clr_flg_menu( *pp, "rub", FLG_MENU_HIDDEN );
+		break;
 	case ITEM_KIND_SPIKE:
 		break;
 	case ITEM_KIND_FOOD:
@@ -1721,7 +1842,8 @@ char	*cb_menu_item_fill_lamp( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	lamp = &(lamp[EQUIP_KIND_LIGHT_SOURCE]);
 
-	tab = get_light_tab( lamp->dat.light.kind );
+	tab = get_light_tab( lamp->dat.light.kind,
+			lamp->dat.light.wish_level );
 
 	if( (lamp->kind != ITEM_KIND_LIGHT) || !tab->flg_fill ){
 		print_msg( FLG_NULL, MSG_ERR_FILL_LAMP );
@@ -1994,7 +2116,8 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 
 			msg = MSG( ls_equip_msg[j].n_msg );
 
-			sprintf( ls[k].path, "/equip/%ld%c",
+			sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+					"/equip/%ld%c",
 					i, (char)('A' + j) );
 			str_nz_cpy( ls[k].kind, "<Branch>",
 					MENU_KIND_MAX_LEN );
@@ -2002,12 +2125,14 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
 			if( equip[eq_k].kind == ITEM_KIND_NULL ){
-				sprintf( ls[k].msg,
+				sn_printf( ls[k].msg,
+						MENU_MSG_MAX_LEN,
 						MSG_FMT_EQUIP_NULL,
 						equip_ttl_max_len,
 						msg );
 			} else {
-				sprintf( ls[k].msg,
+				sn_printf( ls[k].msg,
+						MENU_MSG_MAX_LEN,
 						MSG_FMT_EQUIP,
 						equip_ttl_max_len,
 						msg,
@@ -2019,7 +2144,7 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 			k++;
 		}
 
-		sprintf( ls[k].path,
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
 				"/equip/%ld%s", i, "item" );
 		str_nz_cpy( ls[k].kind, "<Branch>",
 				MENU_KIND_MAX_LEN );
@@ -2154,7 +2279,8 @@ char	*menu_equip_wear_sel( menu_t **pp, menu_t **dflt )
 		if( p == item )
 			break;
 
-		sprintf( ls[k].path, "/wear/%c", (char)('A' + i) );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/wear/%c", (char)('A' + i) );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
@@ -2591,7 +2717,8 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 			k++;
 		}
 
-		sprintf( ls[k].path, "/save load list/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/save load list/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
@@ -2756,7 +2883,7 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 			p = item->next;
 		j = 0;
 		if( (p == NULL) || (p == item) ){
-			sprintf( ls[k].path,
+			sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
 					"/identify item/unknown %c",
 					(char)('A' + i) );
 			str_nz_cpy( ls[k].kind, "<Item>",
@@ -2778,7 +2905,7 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 			if( (pty->mbr[i] == mbr) && (dflt == NULL) )
 				dflt = &(ls[k]);
 
-			sprintf( ls[k].path,
+			sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
 					"/identify item/%c",
 					(char)('A' + j) );
 			str_nz_cpy( ls[k].kind, "<Item>",
@@ -2900,7 +3027,8 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 		if( !chk_flg( pty->mbr[i]->stat, FLG_STAT_DEAD ) )
 			continue;
 
-		sprintf( ls[k].path, "/resurrection/%c",
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/resurrection/%c",
 				(char)('A' + i) );
 		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
@@ -2923,7 +3051,8 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 		if( !chk_flg( pet[i]->stat, FLG_STAT_DEAD ) )
 			continue;
 
-		sprintf( ls[k].path, "/resurrection/%c",
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/resurrection/%c",
 				(char)('A' + i + MBR_MAX_N) );
 		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
