@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.36 2008/02/04 04:27:52 bowkenken Exp $
+* $Id: msg.c,v 1.40 2008/08/18 08:25:05 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -67,8 +67,13 @@
 
 /* ơ֥κ */
 #define	LANG_TAB_MAX_N	64
+
 /* ǥեȤθ */
-#define	STR_DFLT_LANG	"ja_JP.eucJP"
+#ifdef	D_DOS
+# define	STR_DFLT_LANG	"ja_JP.SJIS"
+#else
+# define	STR_DFLT_LANG	"ja_JP.eucJP"
+#endif
 
 /* μ */
 static lang_kind_t	g_lang_kind, g_lang_kind_next;
@@ -129,7 +134,13 @@ typedef struct {
 
 /* åơ֥ */
 
-static msg_t	all_lang_msg[LANG_KIND_MAX_N][N_MSG_MAX_N] = {
+static msg_t	all_lang_msg[LANG_KIND_MAX_N][N_MSG_MAX_N];
+
+/* ֥å 0 */
+
+#define	SEL_MSG_BLOCK_0
+static msg_t	all_lang_msg_0[LANG_KIND_MAX_N]
+		[N_MSG__MSG_BLOCK_0_END_ + 1] = {
 	{
 #include	"msg-eng.h"
 	},
@@ -151,6 +162,35 @@ static msg_t	all_lang_msg[LANG_KIND_MAX_N][N_MSG_MAX_N] = {
 #include	"msg-jpn-sjis.h"
 	},
 };
+#undef	SEL_MSG_BLOCK_0
+
+/* ֥å 1 */
+
+#define	SEL_MSG_BLOCK_1
+static msg_t	all_lang_msg_1[LANG_KIND_MAX_N]
+		[N_MSG__MSG_BLOCK_1_END_ - N_MSG__MSG_BLOCK_0_END_ + 1] = {
+	{
+#include	"msg-eng.h"
+	},
+	{
+#ifdef	D_DOS
+# include	"msg-jpn-sjis.h"
+#else	/* D_DOS */
+# include	"msg-jpn.h"
+#endif	/* D_DOS */
+	},
+	{
+#ifdef	D_DOS
+# include	"msg-jpn-sjis.h"
+#else	/* D_DOS */
+# include	"msg-jpn-utf8.h"
+#endif	/* D_DOS */
+	},
+	{
+#include	"msg-jpn-sjis.h"
+	},
+};
+#undef	SEL_MSG_BLOCK_1
 
 /* åƤʤåѤΥǡ */
 static bool_t	flg_msg_def[N_MSG_MAX_N];
@@ -162,14 +202,35 @@ static bool_t	flg_msg_def[N_MSG_MAX_N];
 void	init_msg( void )
 {
 	bool_t	flg_exit;
+	long	block_bgn_n, block_end_n;
 	char	*lang;
 	long	lang_tab_kind;
-	long	m;
-	long	k;
-	long	i;
+	long	l, i, k, m;
 
 	flg_exit = FALSE;
 
+	block_bgn_n = 0;
+	block_end_n = N_MSG__MSG_BLOCK_0_END_;
+	for( l = 0; l < LANG_KIND_MAX_N; l++ ){
+		for( i = block_bgn_n; i <= block_end_n; i++ ){
+			long	n;
+
+			n = i - block_bgn_n;
+			all_lang_msg[l][i] = all_lang_msg_0[l][n];
+		}
+	}
+
+	block_bgn_n = N_MSG__MSG_BLOCK_0_END_ + 1;
+	block_end_n = N_MSG__MSG_BLOCK_1_END_;
+	for( l = 0; l < LANG_KIND_MAX_N; l++ ){
+		for( i = block_bgn_n; i <= block_end_n; i++ ){
+			long	n;
+
+			n = i - block_bgn_n;
+			all_lang_msg[l][i] = all_lang_msg_1[l][n];
+		}
+	}
+
 	/* Ķѿθͤ */
 
 	if( g_language == NULL ){
@@ -257,6 +318,14 @@ void	init_msg( void )
 		exit_game( EXIT_FAILURE );
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_msg( void )
+{
+}
+
 /***************************************************************
 * åθ
 * lang_kind_t kind : μ
@@ -463,12 +532,25 @@ long	str_len_draw_japanese_euc( const char *s )
 {
 	long	len;
 
-	for( len = 0; *s != '\0'; len++, s++ ){
-		unsigned char	c;
+	len = 0;
+
+	while( *s != '\0' ){
+		unsigned long	c;
 
 		c = (unsigned char)*s;
-		if( (0x80 <= c) && (c <= 0x9f) )
-			len--;
+		if( c >= 0xa0 ){
+			len += 2;
+			s += 2;
+		} else if( c == 0x8e ){
+			len += 1;
+			s += 2;
+		} else if( c == 0x8f ){
+			len += 2;
+			s += 3;
+		} else {
+			len += 1;
+			s += 1;
+		}
 	}
 
 	return len;
@@ -483,43 +565,25 @@ long	str_len_draw_japanese_euc( const char *s )
 long	str_len_draw_japanese_utf_8( const char *s )
 {
 	long	len;
-	unsigned char	c;
-	long	skip_n;
-	long	i;
+	unsigned long	c;
 
 	len = 0;
-	for( ; *s != '\0'; s++ ){
+	while( *s != '\0' ){
 		c = (unsigned char)*s;
-		skip_n = 0;
 
 		if( (c & 0x80) == 0x00 ){
 			len++;
+			s++;
 			continue;
-		} else if( (c & 0xe0) == 0xc0 ){
-			skip_n = 2;
-		} else if( (c & 0xf0) == 0xe0 ){
-			skip_n = 3;
-		} else if( (c & 0xf8) == 0xf0 ){
-			skip_n = 4;
-		} else if( (c & 0xfc) == 0xf8 ){
-			skip_n = 5;
-		} else if( (c & 0xfe) == 0xfc ){
-			skip_n = 6;
 		}
 
 		len += 2;
 		s++;
-		for( i = 1; i < skip_n; i++ ){
+		while( *s != '\0' ){
 			c = (unsigned char)*s;
 
-			if( c == '\0' ){
-				s--;
+			if( (c & 0xc0) != 0x80 )
 				break;
-			}
-			if( (c & 0xc0) != 0x80 ){
-				s--;
-				break;
-			}
 
 			s++;
 		}
