@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.96 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: request.c,v 1.99 2008/05/17 18:29:59 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -44,9 +44,6 @@
 # define	FLG_DEBUG_REQUEST	0
 #endif
 
-/* Υޥ */
-#define	BAR_MASTER_SEX	MALE
-
 /* Υ˥塼ꥹȤΥڡιܿ */
 #define	MENU_REQUEST_N_PER_PAGE	10
 
@@ -84,6 +81,9 @@
 /* ¾ΰꥹȤ򸫤μ */
 #define	REQUEST_REFRESH_PRIZE	((gold_t)(1 * MBR_MAX_N))
 
+/* ̾ɽʸ */
+#define	REQUEST_NAME_MIN_LEN	14
+
 /***************************************************************
 * 󽷤ζȷиͤΨ
 ***************************************************************/
@@ -138,6 +138,14 @@ void	init_request( void )
 		g_request[i].kind = REQUEST_KIND_NULL;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_request( void )
+{
+}
+
 /***************************************************************
 * Ϥ
 ***************************************************************/
@@ -1216,9 +1224,6 @@ bool_t	set_request_msg( request_t *req )
 			buf_idx--;
 		} else if( fmt[fmt_idx] & 0x80 ){
 			buf[buf_idx] = fmt[fmt_idx];
-			buf_idx++;
-			fmt_idx++;
-			buf[buf_idx] = fmt[fmt_idx];
 		} else if( fmt[fmt_idx] == '$' ){
 			if( fmt[fmt_idx + 1] == '$' ){
 				buf[buf_idx] = fmt[fmt_idx];
@@ -1245,7 +1250,7 @@ bool_t	set_request_msg( request_t *req )
 		else
 			name = cv_idx_to_contract_name( req );
 
-		sprintf( str_contract,
+		sn_printf( str_contract, REQUEST_MSG_MAX_LEN,
 				MSG_REQUEST_CONTRACT_FMT, name );
 	} else {
 		str_nz_cpy( str_contract,
@@ -1341,7 +1346,7 @@ void	set_request_msg_var_dun_min_lev(
 	if( req == NULL )
 		return;
 
-	sprintf( buf, "%ld", req->dun_min_lev );
+	sn_printf( buf, REQUEST_MSG_MAX_LEN, "%ld", req->dun_min_lev );
 }
 
 /***************************************************************
@@ -1361,7 +1366,7 @@ void	set_request_msg_var_dun_max_lev(
 	if( req == NULL )
 		return;
 
-	sprintf( buf, "%ld", req->dun_max_lev );
+	sn_printf( buf, REQUEST_MSG_MAX_LEN, "%ld", req->dun_max_lev );
 }
 
 /***************************************************************
@@ -1384,29 +1389,29 @@ void	set_request_msg_var_dun_lev_range(
 		return;
 
 	if( req->dun_min_lev >= +1 ){
-		sprintf( str_min, MSG_FLOOR_FMT,
+		sn_printf( str_min, 32, MSG_FLOOR_FMT,
 				labs( req->dun_min_lev ) );
 	} else if( req->dun_min_lev <= -1 ){
-		sprintf( str_min, MSG_BASE_FMT,
+		sn_printf( str_min, 32, MSG_BASE_FMT,
 				labs( req->dun_min_lev ) );
 	} else {
-		sprintf( str_min, MSG_S, MSG_GROUND );
+		sn_printf( str_min, 32, MSG_S, MSG_GROUND );
 	}
 
 	if( req->dun_max_lev >= +1 ){
-		sprintf( str_max, MSG_FLOOR_FMT,
+		sn_printf( str_max, 32, MSG_FLOOR_FMT,
 				labs( req->dun_max_lev ) );
 	} else if( req->dun_max_lev <= -1 ){
-		sprintf( str_max, MSG_BASE_FMT,
+		sn_printf( str_max, 32, MSG_BASE_FMT,
 				labs( req->dun_max_lev ) );
 	} else {
-		sprintf( str_max, MSG_S, MSG_GROUND );
+		sn_printf( str_max, 32, MSG_S, MSG_GROUND );
 	}
 
 	if( req->dun_min_lev == req->dun_max_lev ){
-		sprintf( buf, MSG_REQUEST_DUN_LEV, str_max );
+		sn_printf( buf, 32, MSG_REQUEST_DUN_LEV, str_max );
 	} else {
-		sprintf( buf, MSG_REQUEST_DUN_LEV_RANGE,
+		sn_printf( buf, 32, MSG_REQUEST_DUN_LEV_RANGE,
 				str_min, str_max );
 	}
 }
@@ -1465,7 +1470,8 @@ void	set_request_msg_var_rare_goods(
 	if( tab == NULL )
 		return;
 
-	sprintf( buf, MSG_REQUEST_VAR_QUOTE, tab->name );
+	sn_printf( buf, REQUEST_MSG_MAX_LEN,
+			MSG_REQUEST_VAR_QUOTE, tab->name );
 }
 
 /***************************************************************
@@ -1500,10 +1506,12 @@ void	set_request_msg_var_mnstr(
 
 		tab = get_mnstr_tab( req->mnstr_kind, req->dun_true_lev );
 		if( tab == NULL ){
-			sprintf( buf, MSG_REQUEST_VAR_QUOTE,
+			sn_printf( buf, REQUEST_MSG_MAX_LEN,
+					MSG_REQUEST_VAR_QUOTE,
 					MSG_MNSTR_UNKNOWN );
 		} else {
-			sprintf( buf, MSG_REQUEST_VAR_QUOTE,
+			sn_printf( buf, REQUEST_MSG_MAX_LEN,
+					MSG_REQUEST_VAR_QUOTE,
 					tab->name );
 		}
 	}
@@ -1526,7 +1534,8 @@ void	set_request_msg_var_mnstr_n(
 	if( req == NULL )
 		return;
 
-	sprintf( buf, MSG_REQUEST_MNSTR_N, req->mnstr_n );
+	sn_printf( buf, REQUEST_MSG_MAX_LEN,
+			MSG_REQUEST_MNSTR_N, req->mnstr_n );
 }
 
 /***************************************************************
@@ -1744,10 +1753,12 @@ void	set_request_msg_var_ls(
 		*n_msg_idx = get_ls_n_msg_idx_randm( ls_msg );
 
 	if( flg_quote ){
-		sprintf( buf, MSG_REQUEST_VAR_QUOTE,
+		sn_printf( buf, REQUEST_MSG_MAX_LEN,
+				MSG_REQUEST_VAR_QUOTE,
 				MSG( ls_msg[*n_msg_idx] ) );
 	} else {
-		sprintf( buf, MSG_S,
+		sn_printf( buf, REQUEST_MSG_MAX_LEN,
+				MSG_S,
 				MSG( ls_msg[*n_msg_idx] ) );
 	}
 }
@@ -1761,6 +1772,8 @@ void	set_request_msg_var_ls(
 bool_t	set_request_heading( request_t *req )
 {
 	char	*str_contract;
+	char	*name;
+	long	len;
 
 	if( req == NULL )
 		return FALSE;
@@ -1777,9 +1790,14 @@ bool_t	set_request_heading( request_t *req )
 		str_contract = MSG_REQUEST_CONTRACT_STILL;
 	}
 
-	sprintf( req->heading, MSG_REQUEST_HEADING_FMT,
+	name = get_request_kind_name( req->kind );
+	len = get_pading_len( name, REQUEST_NAME_MIN_LEN );
+
+	sn_printf( req->heading, MENU_MSG_MAX_LEN,
+			MSG_REQUEST_HEADING_FMT,
 			str_contract,
-			get_request_kind_name( req->kind ),
+			len,
+			name,
 			req->dun_max_lev,
 			req->limit - get_game_day(),
 			fmt_gold( req->prize ) );
@@ -2210,6 +2228,8 @@ void	close_all_request( chr_kind_t chr_kind )
 bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 {
 	party_t	*pty = get_party();
+	sex_t	master_sex;
+	const char	*master_name;
 	long	i;
 
 	if( req == NULL )
@@ -2248,14 +2268,19 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 
 	not_join_all_client( req, TRUE );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+	/* åɽ */
+
+	master_sex = get_npc_sex_shop( SHOP_N_BAR );
+	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
+
+	print_words( master_name, master_sex,
 			MSG_WORDS_REQUEST_CLOSE_1_FEMALE,
 			MSG_WORDS_REQUEST_CLOSE_1_MALE );
 
 	add_party_gold( req->prize );
 	exp_party( req->exp, FALSE, TRUE );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+	print_words( master_name, master_sex,
 			MSG_WORDS_REQUEST_CLOSE_2_FEMALE,
 			MSG_WORDS_REQUEST_CLOSE_2_MALE );
 
@@ -2604,7 +2629,7 @@ char	*set_menu_request(
 
 		set_request_heading( &(g_request[i]) );
 
-		sprintf( ls[k].path, "/request/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/request/%ld", i );
 		str_nz_cpy( ls[k].kind, "<OpenWinItem>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A'
@@ -2627,7 +2652,8 @@ char	*set_menu_request(
 			ls[k].accel_key = 'Z';
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			sprintf( ls[k].msg, MSG_MENU_REQUEST_REFRESH,
+			sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+					MSG_MENU_REQUEST_REFRESH,
 					fmt_gold( REQUEST_REFRESH_PRIZE ) );
 			ls[k].call_back = cb_menu_request_refresh;
 			ls[k].arg = NULL;
@@ -2657,7 +2683,8 @@ char	*set_menu_request(
 		ls[k].accel_key = 'Z';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		sprintf( ls[k].msg, MSG_MENU_REQUEST_REFRESH,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_REQUEST_REFRESH,
 				fmt_gold( REQUEST_REFRESH_PRIZE ) );
 		ls[k].call_back = cb_menu_request_refresh;
 		ls[k].arg = NULL;
@@ -2786,6 +2813,8 @@ char	*cb_menu_request_refresh( menu_t **pp, menu_t **dflt )
 bool_t	ask_contract_request( request_t *req )
 {
 	ask_t	ask;
+	sex_t	master_sex;
+	const char	*master_name;
 
 	if( req == NULL )
 		return FALSE;
@@ -2796,7 +2825,9 @@ bool_t	ask_contract_request( request_t *req )
 	if( ask != ASK_YES )
 		return FALSE;
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+	master_sex = get_npc_sex_shop( SHOP_N_BAR );
+	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
+	print_words( master_name, master_sex,
 			MSG_WORDS_REQUEST_CONTRACT_FEMALE,
 			MSG_WORDS_REQUEST_CONTRACT_MALE );
 
@@ -2814,13 +2845,17 @@ bool_t	ask_cancel_request( request_t *req )
 	char	msg[MENU_MSG_MAX_LEN + 1];
 	gold_t	penalty;
 	ask_t	ask;
+	sex_t	master_sex;
+	const char	*master_name;
 
 	if( req == NULL )
 		return FALSE;
 
 	penalty = req->prize * REQUEST_PENALTY_RATE / _100_PERCENT;
 
-	sprintf( msg, MSG_TTL_MENU_REQUEST_MBR_CANCEL, fmt_gold( penalty ) );
+	sn_printf( msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_REQUEST_MBR_CANCEL,
+			fmt_gold( penalty ) );
 	ask = exec_menu_ask( msg, ASK_NO, TRUE );
 	if( ask != ASK_YES )
 		return FALSE;
@@ -2834,7 +2869,9 @@ bool_t	ask_cancel_request( request_t *req )
 
 	not_join_all_client( req, FALSE );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+	master_sex = get_npc_sex_shop( SHOP_N_BAR );
+	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
+	print_words( master_name, master_sex,
 			MSG_WORDS_REQUEST_CANCEL_FEMALE,
 			MSG_WORDS_REQUEST_CANCEL_MALE );
 
