@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: turn.h,v 1.12 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: turn.h,v 1.13 2008/05/15 19:58:29 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TURN_H
@@ -39,19 +39,22 @@
 #define	ADJUST_TURN	1
 
 /* Υ */
-#define	TURN_DAYTIME	((long)(12 * 60 * 60 / 10))
+#define	TURN_DAYTIME	(TURN_A_DAY / 2)
 
 /* Υ */
-#define	TURN_NIGHT	TURN_DAYTIME
+#define	TURN_NIGHT	(TURN_A_DAY / 2)
 
 /* Υ */
-#define	TURN_A_DAY	(TURN_DAYTIME + TURN_NIGHT)
+#define	TURN_A_DAY	(24 * TURN_PER_HOUR)
 
 /* ֤Υ */
-#define	TURN_PER_HOUR	(TURN_A_DAY / 24)
+#define	TURN_PER_HOUR	(60 * TURN_PER_MINUTE)
 
 /* ʬΥ */
-#define	TURN_PER_MINUTE	(TURN_PER_HOUR / 60)
+#define	TURN_PER_MINUTE	(60 / SECOND_PER_TURN)
+
+/* ÿ */
+#define	SECOND_PER_TURN	10
 
 /* νФλ */
 #define	MORNING_HOUR	6
